<?xml version="1.0" encoding="ISO-8859-1"?>

<!-- =========================== MONSOON ================================ -->
<!-- MONSOON configuration process style sheet    (TOP LEVEL)             -->
<!-- Peter Moore 20050323                                                 -->
<!-- (c) Copyright 2004, National Optical Astronomy Observatory, which is -->
<!-- operated for the National Science Foundation by the Association of   -->
<!-- Universities for Research in Astronomy under Cooperative Agreement   -->
<!-- No. AST-0132798.                                                     -->
<!-- ==================================================================== -->

<xsl:stylesheet version = '1.0' xmlns:xsl='http://www.w3.org/1999/XSL/Transform'>

<xsl:output
  method="html"
  version="1.0"
  encoding="iso-8859-1"
  omit-xml-declaration="yes"
  standalone="yes"
  indent="no"
  media-type="application/text" />


<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>


<xsl:template match="System">

  <xsl:variable name="focal_url" select="FPURL/URL" />

  <xsl:element name="html">
    <xsl:element name="head">
      <xsl:element name="title">
        <xsl:text>MONSOON PAN Configuration files for </xsl:text><xsl:value-of select="SystemName/NAME" />
      </xsl:element>
    </xsl:element>
    <xsl:element name="body">
      <xsl:element name="font">
        <xsl:attribute name="color">
          <xsl:text>red</xsl:text>
        </xsl:attribute>
        <xsl:text>## Configuration file generated by CsvGen.xsl Version 0.1</xsl:text> <?dbtimestamp format="Y-m-d H:M:S"?><br/>
      </xsl:element>
      <xsl:choose>
        <xsl:when test="SupervisorURL/URL">
          <xsl:variable name="super_url" select="SupervisorURL/URL" />
          <xsl:for-each select="document($super_url)/Supervisor/SupervisorPANs/PANURL/URL">
            <xsl:call-template name="RunConfig">
              <xsl:with-param name="system_name"><xsl:value-of select="SystemName/NAME" /></xsl:with-param>
              <xsl:with-param name="fp_url"><xsl:value-of select="$focal_url" /></xsl:with-param>
              <xsl:with-param name="pan_url"><xsl:value-of select="." /></xsl:with-param>
            </xsl:call-template>          
          </xsl:for-each>  
        </xsl:when>
        <xsl:otherwise>
          <xsl:call-template name="RunConfig">
            <xsl:with-param name="system_name"><xsl:value-of select="SystemName/NAME" /></xsl:with-param>
            <xsl:with-param name="fp_url"><xsl:value-of select="$focal_url" /></xsl:with-param>
            <xsl:with-param name="pan_url"><xsl:value-of select="PANURL/URL" /></xsl:with-param>
            </xsl:call-template>          
        </xsl:otherwise>
      </xsl:choose>
    </xsl:element>
  </xsl:element>
   
</xsl:template>


<xsl:template name="RunConfig">

  <xsl:param name="system_name" />
  <xsl:param name="fp_url" />
  <xsl:param name="pan_url" />
  
<!-- %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% -->
<!-- Generate Engineering Interface Page Definitions -->
<!-- %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% -->
  <xsl:element name="font">
    <xsl:attribute name="color">
      <xsl:text>red</xsl:text>
    </xsl:attribute>
    <xsl:text>## Monsoon GUI Description File</xsl:text><br/>
    <xsl:text>## Save as </xsl:text>
    <xsl:element name="font">
      <xsl:attribute name="color">
        <xsl:text>blue</xsl:text>
      </xsl:attribute>
      <xsl:text>/usr/Monsoon/cfg/_</xsl:text>    
      <xsl:value-of select="translate($system_name, $ucletters, $lcletters)" />
      <xsl:text>/</xsl:text>
      <xsl:value-of select="translate($system_name, $ucletters, $lcletters)" /><xsl:text>_guiCategories.txt </xsl:text>
    </xsl:element>
  </xsl:element>
  <xsl:element name="pre">
    <xsl:attribute name="width">
      <xsl:text>200</xsl:text>
    </xsl:attribute>
    <xsl:for-each select="document($pan_url)/PAN/PANGUIPages/PAGE">
      <xsl:text>&#x0A;</xsl:text> 
      <xsl:value-of select="NAME" />
      <xsl:text> = 0x</xsl:text>
      <xsl:value-of select="INDEX" />
    </xsl:for-each>          
  </xsl:element>


<!-- %%%%%%%%%%%%%%%%%%%%%%%%%%% -->
<!-- Generate Configuration File -->
<!-- %%%%%%%%%%%%%%%%%%%%%%%%%%% -->
<!-- Process PAN signals -->
  <xsl:element name="font">
    <xsl:attribute name="color">
      <xsl:text>red</xsl:text>
    </xsl:attribute>
    <xsl:text>## Configuration segment for PAN </xsl:text><xsl:value-of select="document($pan_url)/PAN/PANName/NAME" /><br/>
    <xsl:text>## Save as </xsl:text>
    <xsl:element name="font">
      <xsl:attribute name="color">
        <xsl:text>blue</xsl:text>
      </xsl:attribute>
      <xsl:text>/usr/Monsoon/cfg/_</xsl:text>    
      <xsl:value-of select="translate($system_name, $ucletters, $lcletters)" />
      <xsl:text>/</xsl:text>
      <xsl:value-of select="translate($system_name, $ucletters, $lcletters)" /><xsl:text>_Config.csv </xsl:text><br/>
    </xsl:element>
    <xsl:text>## PAN Attribute Name,DHE Func Name,Base Address,Number of elements,Creg,Set Method,Read Method,PANType,DHEType,Coef1,Coef2,Function ID,Min Value,Max Value,UnitName,HelpText</xsl:text><br/>
  </xsl:element>
  <xsl:element name="pre">
    <xsl:attribute name="width">
      <xsl:text>200</xsl:text>
    </xsl:attribute>
    <xsl:text>#</xsl:text>
    <xsl:text>&#x0A;</xsl:text> 
    <xsl:text>## Configuration segment for DHE Signals </xsl:text>
    <xsl:text>&#x0A;</xsl:text> 
    <xsl:text>#</xsl:text>
    <xsl:for-each select="document($pan_url)/PAN/PANSignals/SIGNAL">
      <xsl:for-each select="SIG_DESTINATION">
        <xsl:if test="DEST_URL/URL">          
          <xsl:call-template name="ConfigSignal">
            <xsl:with-param name="sourceSig" select="../SIG_NAME" />                            
            <xsl:with-param name="sourcePage" select="../DISP_PAGE" />                            
            <xsl:with-param name="url" select="DEST_URL/URL" />
            <xsl:with-param name="con" select="SIGNAL/SIG_DESIG/CONNECTOR" />
            <xsl:with-param name="pin" select="SIGNAL/SIG_DESIG/PIN" />
            <xsl:with-param name="pan_url" select="$pan_url" />
          </xsl:call-template>
        </xsl:if>
      </xsl:for-each>
    </xsl:for-each>

<!-- Process software signals -->
    <xsl:variable name="sw" select="document($pan_url)/PAN/SoftwareURL/URL" />
    <xsl:text>&#x0A;</xsl:text> 
    <xsl:text>#</xsl:text>
    <xsl:text>&#x0A;</xsl:text> 
    <xsl:text>## Configuration segment for Detector library </xsl:text>
    <xsl:text>&#x0A;</xsl:text> 
    <xsl:text>#</xsl:text>
    <xsl:for-each select="document($sw)/Software/SoftwareSignals/SIGNAL/SIG_DESTINATION">
      <xsl:if test="DEST_URL/URL">          
        <xsl:call-template name="ConfigSignal">
          <xsl:with-param name="sourceSig" select="../SIG_NAME" />                            
          <xsl:with-param name="sourcePage" select="../DISP_PAGE" />                            
          <xsl:with-param name="url" select="DEST_URL/URL" />
          <xsl:with-param name="con" select="SIGNAL/SIG_DESIG/CONNECTOR" />
          <xsl:with-param name="pin" select="SIGNAL/SIG_DESIG/PIN" />
          <xsl:with-param name="pan_url" select="$pan_url" />
        </xsl:call-template>
      </xsl:if>
    </xsl:for-each>

<!-- Process Focal Plane signals -->
    <xsl:text>&#x0A;</xsl:text>
    <xsl:for-each select="document($fp_url)/FP/FPSegment/PANURL[URL=$pan_url]/../FPGeometry/Detector">
      <xsl:text>#</xsl:text>
      <xsl:text>&#x0A;</xsl:text> 
      <xsl:text>## Configuration segment for detector </xsl:text><xsl:value-of select="DetectorName/NAME" />
      <xsl:text>&#x0A;</xsl:text> 
      <xsl:text>#</xsl:text>
      <xsl:for-each select="DetectorSignals/SIGNAL">
	    <xsl:for-each select="SIG_DESTINATION">
          <xsl:if test="DEST_URL/URL">          
            <xsl:call-template name="ConfigSignal">
              <xsl:with-param name="sourceSig" select="../SIG_NAME" />                            
              <xsl:with-param name="sourcePage" select="../DISP_PAGE" />                            
              <xsl:with-param name="url" select="DEST_URL/URL" />
              <xsl:with-param name="con" select="SIGNAL/SIG_DESIG/CONNECTOR" />
              <xsl:with-param name="pin" select="SIGNAL/SIG_DESIG/PIN" />
              <xsl:with-param name="pan_url" select="$pan_url" />
            </xsl:call-template>
          </xsl:if>
        </xsl:for-each>
      </xsl:for-each>
    </xsl:for-each>
  </xsl:element>

<!-- %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% -->
<!-- Generate Sequencer DEF stub file -->
<!-- %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% -->
  <xsl:element name="font">
    <xsl:attribute name="color">
      <xsl:text>red</xsl:text>
    </xsl:attribute>
    <xsl:text>## Sequencer code stub for </xsl:text><xsl:value-of select="document($fp_url)/FP/FPSegment/PANURL[URL=$pan_url]/../FPGeometry/Detector/DetectorName/NAME" /><br/>
    <xsl:text>## Save as </xsl:text>
    <xsl:element name="font">
      <xsl:attribute name="color">
        <xsl:text>blue</xsl:text>
      </xsl:attribute>
      <xsl:value-of select="translate($system_name, $ucletters, $lcletters)" /><xsl:text>_sequencer.asm </xsl:text>
    </xsl:element>
    <xsl:text>in PAN directory </xsl:text>
    <xsl:element name="font">
      <xsl:attribute name="color">
        <xsl:text>blue</xsl:text>
      </xsl:attribute>
      <xsl:text>/usr/Monsoon/cfg/_</xsl:text>    
      <xsl:value-of select="translate($system_name, $ucletters, $lcletters)" /><br/>
    </xsl:element>
    <xsl:text>## and assemble (after completing the code!) with </xsl:text>
    <xsl:element name="font">
      <xsl:attribute name="color">
        <xsl:text>blue</xsl:text>
      </xsl:attribute>
      <xsl:text>asm4 </xsl:text>
      <xsl:value-of select="translate($system_name, $ucletters, $lcletters)" /><xsl:text>_sequencer.asm </xsl:text>
      <xsl:value-of select="translate($system_name, $ucletters, $lcletters)" /><xsl:text>_sequencer.ucd </xsl:text><br/>
    </xsl:element>
    <xsl:text>## Use asm4 without parameters to get the help and options page</xsl:text><br/>
  </xsl:element>
  <xsl:element name="pre">
    <xsl:attribute name="width">
      <xsl:text>200</xsl:text>
    </xsl:attribute>
    <xsl:text>******************************************************&#x0A;</xsl:text>
    <xsl:text>** PROJECT     : &#x0A;</xsl:text>
    <xsl:text>** TITLE       : </xsl:text><xsl:value-of select="translate($system_name, $lcletters, $ucletters)" /><xsl:text>&#x0A;</xsl:text> 
    <xsl:text>**             : &#x0A;</xsl:text>
    <xsl:text>** VERSION     : 0.00&#x0A;</xsl:text>
    <xsl:text>** DATE        : &#x0A;</xsl:text>
    <xsl:text>** AUTHOR      : XML Stub Generator&#x0A;</xsl:text>
    <xsl:text>** HISTORY     : VERSION 0 -- &#x0A;</xsl:text>
    <xsl:text>**             : &#x0A;</xsl:text> 
    <xsl:text>** DESCRIPTION : &#x0A;</xsl:text> 
    <xsl:text>**             : &#x0A;</xsl:text> 
    <xsl:text>******************************************************&#x0A;</xsl:text>
    <xsl:text>**&#x0A;</xsl:text>
    <xsl:text>**             Constant definitions&#x0A;</xsl:text>
    <xsl:text>**&#x0A;</xsl:text>
    <xsl:text>** Jump flag constants - Bit positions in CMD Register&#x0A;</xsl:text>
    <xsl:text>DEF #SYNC        1                  * Jump on sync bit high&#x0A;</xsl:text>
    <xsl:text>DEF #ITC         2                  * Jump on Integration time expired&#x0A;</xsl:text>
    <xsl:text>DEF #START       3                  * Jump on start exposure flag set&#x0A;</xsl:text>
    <xsl:text>DEF #VCTR_1      4                  * Jump on start vector bit value   1&#x0A;</xsl:text>
    <xsl:text>DEF #VCTR_2      5                  * Jump on start vector bit value   2&#x0A;</xsl:text>
    <xsl:text>DEF #VCTR_3      6                  * Jump on start vector bit value   4&#x0A;</xsl:text>
    <xsl:text>DEF #VCTR_4      7                  * Jump on start vector bit value   8&#x0A;</xsl:text>
    <xsl:text>DEF #VCTR_5      8                  * Jump on start vector bit value  16&#x0A;</xsl:text>
    <xsl:text>DEF #VCTR_6      9                  * Jump on start vector bit value  32&#x0A;</xsl:text>
    <xsl:text>DEF #VCTR_7     10                  * Jump on start vector bit value  64&#x0A;</xsl:text>
    <xsl:text>DEF #VCTR_8     11                  * Jump on start vector bit value 128&#x0A;</xsl:text>

    <xsl:call-template name="UsrFlagAssig">
      <xsl:with-param name="pan_url" select="$pan_url" />
    </xsl:call-template>
<!--
    <xsl:text>DEF #USR_1      12                  * Jump on user mode bit value 1&#x0A;</xsl:text>
    <xsl:text>DEF #USR_2      13                  * Jump on user mode bit value 2&#x0A;</xsl:text>
    <xsl:text>DEF #USR_3      14                  * Jump on user mode bit value 4&#x0A;</xsl:text>
    <xsl:text>DEF #USR_4      15                  * Jump on user mode bit value 8&#x0A;</xsl:text>  
-->
    <xsl:text>**&#x0A;</xsl:text>
    <xsl:text>** EFR Reg constants&#x0A;</xsl:text>
    <xsl:text>DEF #KILL_EXPFLG    x00000001       * Cancel start exposure flag using the EFR register&#x0A;</xsl:text> 
    <xsl:text>DEF #STRT_INTCNTR   x00000002       * Start the integration time counter using the EFR register&#x0A;</xsl:text>
    <xsl:text>DEF #STOP_INTCNTR   x00000004       * Stop the integration time counter using the EFR register&#x0A;</xsl:text>
    <xsl:text>DEF #LSR_AUTO_KILL  x00000100       * Enables automatic board select cancel after an LSR instruction&#x0A;</xsl:text>
    <xsl:text>DEF #LSR_MAN_RESET  x00000200       * Disables automatic board select cancel. LSR will remain active until an LSR #DSLCT is issued&#x0A;</xsl:text> 
    <xsl:text>DEF #SET_SYNC_LOW   x00004000       * If enabled as master DHE, set sync bit low after sync delay&#x0A;</xsl:text>
    <xsl:text>DEF #SET_SYNC_HIGH  x00008000       * If enabled as master DHE, set sync signal high immediately&#x0A;</xsl:text>
    <xsl:text>DEF #KILLANDSYNC    x00004001       * Set sync low and kill start exposure flag&#x0A;</xsl:text>
    <xsl:text>**&#x0A;</xsl:text>
    <xsl:text>** Mode register constants&#x0A;</xsl:text>
    <xsl:text>DEF #RESET       0                  * Mode register constant for board reset operation&#x0A;</xsl:text>
    <xsl:text>DEF #READ        1                  * Mode register constant for read operation&#x0A;</xsl:text>
    <xsl:text>DEF #WRITE16     2                  * Mode register constant for 16 bit write operation&#x0A;</xsl:text>
    <xsl:text>DEF #WRITE32     3                  * Mode register constant for 32 bit write operation&#x0A;</xsl:text>
    <xsl:text>**&#x0A;</xsl:text>
    <xsl:text>** LSR Board select assignments&#x0A;</xsl:text>
    <xsl:call-template name="BoardAssig">
      <xsl:with-param name="dhe_url" select="document($pan_url)/PAN/DHEChassisURL/URL" />
    </xsl:call-template>
    <xsl:text>**&#x0A;</xsl:text>
    <xsl:text>** LOOP REGISTER assignments&#x0A;</xsl:text>
    <xsl:call-template name="LoopRegAssig">
      <xsl:with-param name="pan_url" select="$pan_url" />
    </xsl:call-template>
    <xsl:text>**&#x0A;</xsl:text>
    <xsl:text>** CCDCLK BOARD ADDRESS POINTERS&#x0A;</xsl:text>
    <xsl:text>DEF #CLKPORT     x0000&#x0A;</xsl:text>
    <xsl:text>DEF #FBIAS0123   x0001&#x0A;</xsl:text>
    <xsl:text>DEF #FBIAS4567   x0002&#x0A;</xsl:text>
    <xsl:text>**&#x0A;</xsl:text>
    <xsl:text>** CCDACQ BOARD ADDRESS POINTERS&#x0A;</xsl:text>
    <xsl:text>DEF #CDSREG      x0000&#x0A;</xsl:text>
    <xsl:text>DEF #DOPREG      x0001&#x0A;</xsl:text>
    <xsl:text>DEF #BRSTCMD     x0004&#x0A;</xsl:text>
    <xsl:text>**&#x0A;</xsl:text>
    <xsl:text>** Clock signal definitions generated here&#x0A;</xsl:text>    
    <xsl:for-each select="document($fp_url)/FP/FPSegment/PANURL[URL=$pan_url]/../FPGeometry/Detector">
      <xsl:for-each select="DetectorSignals/SIGNAL[@type='clock']">
        <xsl:call-template name="FindSignal">
          <xsl:with-param name="sourceSig" select="SIG_NAME" />                            
          <xsl:with-param name="sourcePage" select="DISP_PAGE" />                            
          <xsl:with-param name="url" select="SIG_DESTINATION/DEST_URL/URL" />
          <xsl:with-param name="con" select="SIG_DESTINATION/SIGNAL/SIG_DESIG/CONNECTOR" />
          <xsl:with-param name="pin" select="SIG_DESTINATION/SIGNAL/SIG_DESIG/PIN" />
          <xsl:with-param name="pan_url" select="$pan_url" />
        </xsl:call-template>        
        <xsl:text>&#x0A;</xsl:text>        
      </xsl:for-each>
    </xsl:for-each>
    <xsl:text>**&#x0A;</xsl:text>
    <xsl:text>*************************&#x0A;</xsl:text>
    <xsl:text>** CDS BIT DEFINITIONS **&#x0A;</xsl:text>
    <xsl:text>*************************&#x0A;</xsl:text>
    <xsl:text>DEF #CDS_ADR    x0100                 * Channel address of CDS (0x100 = channel 0, 0x200 = channel 1, 0x300 = channel 0 and 1, etc.).&#x0A;</xsl:text> 
    <xsl:text>DEF #CDS_GBL    b1000000000000000     * Global address strobe for CTC and FP Trigger&#x0A;</xsl:text>
    <xsl:text>DEF #CDS_CTC    b0000000000000001     * Trigger an ADC conversion cycle&#x0A;</xsl:text>
    <xsl:text>DEF #CDS_INV    b0000000000000010     * Connect the Inverted the signal&#x0A;</xsl:text>
    <xsl:text>DEF #CDS_NIN    b0000000000000100     * Connect the Non-Inverted the signal&#x0A;</xsl:text>
    <xsl:text>DEF #CDS_INT    b0000000000001000     * Integrate&#x0A;</xsl:text>
    <xsl:text>DEF #CDS_DCR    b0000000000010000     * Apply the DC Restore clamp&#x0A;</xsl:text>
    <xsl:text>DEF #CDS_RST    b0000000000100000     * Reset the integrator&#x0A;</xsl:text>
    <xsl:text>DEF #CDS_TFP    b0000000001000000     * Trigger the front panel test point&#x0A;</xsl:text>
    <xsl:text>**&#x0A;</xsl:text>
    <xsl:text>********************************&#x0A;</xsl:text>
    <xsl:text>** PATTERN MEMORY DEFINITIONS **&#x0A;</xsl:text>
    <xsl:text>********************************&#x0A;</xsl:text>
    <xsl:text>** PATTERN MEMORY SEGMENTATION MAP&#x0A;</xsl:text>
    <xsl:text>DEF #PATSEG_00      x0000             * Pattern memory origin - Initialization stuff - for example&#x0A;</xsl:text>
    <xsl:text>DEF #PATSEG_CLR     x0020             * Pattern memory origin - CCD CLEAR VECTORS - for example&#x0A;</xsl:text>
    <xsl:text>DEF #PATSEG_INIT    x0040             * Pattern memory origin - CCD READ INITIALIZATION - for example&#x0A;</xsl:text>
    <xsl:text>DEF #PATSEG_PAR     x0060             * Pattern memory origin - CCD PARALLEL SHIFT VECTORS - for example&#x0A;</xsl:text>
    <xsl:text>DEF #PATSEG_SER     x0080             * Pattern memory origin - CCD SERIAL SHIFT VECTORS - for example&#x0A;</xsl:text>
    <xsl:text>DEF #PATSEG_CDS     x00A0             * Pattern memory origin - CCD CDS OPERATION VECTORS - for example&#x0A;</xsl:text>
    <xsl:text>**&#x0A;</xsl:text>
    <xsl:text>** PATTERN MEMORY DATA DEFINITIONS&#x0A;</xsl:text>
    <xsl:text>ORG PAT #PATSEG_00                    * ********* GENERAL CONSTANTS KEPT IN PAT MEM *********&#x0A;</xsl:text> 
    <xsl:text>PAT #KILL_EXPFLG    #KILL_EXPFLG      * We can use the same label name here because they are in different contexts&#x0A;</xsl:text>
    <xsl:text>PAT #STRT_INTCNTR   #STRT_INTCNTR     * The definition earlier points to a data value. The label here points to&#x0A;</xsl:text>
    <xsl:text>PAT #STOP_INTCNTR   #STOP_INTCNTR     * a pattern memory address that contains the actual pattern data&#x0A;</xsl:text>
    <xsl:text>**&#x0A;</xsl:text>
    <xsl:text>*************************************&#x0A;</xsl:text>
    <xsl:text>* PROGRAM CODE SEGMENT STARTS HERE **&#x0A;</xsl:text>
    <xsl:text>*************************************&#x0A;</xsl:text>
    <xsl:text>** EXECUTIVE ROUTINE&#x0A;</xsl:text>
    <xsl:text>#MAIN   DMS 200                       * Allow the PAN to finish abusing the sequencer bus.&#x0A;</xsl:text>
    <xsl:text>        CAL #INIT                     * Establish initial conditions&#x0A;</xsl:text>
    <xsl:text>#EXEC   JCB #GOBABY #START            * If 'START EXPOSURE' flag set, Jump to label 'GOBABY'&#x0A;</xsl:text>
    <xsl:text>        JMP #EXEC                     * Else jump back to exec loop: Looping and waiting for start exposure command&#x0A;</xsl:text>
    <xsl:text>#GOBABY LPP #KILL_EXPFLG              * Kill the 'START EXPOSURE' flag (PATTERN = 0x00000001)&#x0A;</xsl:text>
    <xsl:text>        LMR #WRITE32                  * by setting 32 bit write mode&#x0A;</xsl:text>
    <xsl:text>        LSR #MCB                      * and writing to the EFR&#x0A;</xsl:text>
    <xsl:text>        JCB #STUB_1 #VCTR_1           * Once here, jump on independent start exposure vector bits&#x0A;</xsl:text>
    <xsl:text>        JCB #STUB_2 #VCTR_2           * &#x0A;</xsl:text>
    <xsl:text>        JCB #STUB_3 #VCTR_3           * &#x0A;</xsl:text>
    <xsl:text>        JCB #STUB_4 #VCTR_4           * For example !&#x0A;</xsl:text>
    <xsl:text>        JMP #EXEC                     * No flags set (i.e. start vector was zero) so go home.&#x0A;</xsl:text>
    <xsl:text>**&#x0A;</xsl:text>
    <xsl:text>**&#x0A;</xsl:text>
    <xsl:text>#INIT   RET                           * Put detector and DHE initialization code here: Called once&#x0A;</xsl:text>
    <xsl:text>#STUB_1 RET                           * Typically put a call to a clear routine here,&#x0A;</xsl:text>
    <xsl:text>#STUB_2 RET                           * and maybe a call to a single detector read,&#x0A;</xsl:text>
    <xsl:text>#STUB_3 RET                           * then, maybe call to a clear followed by integration + readout here&#x0A;</xsl:text>
    <xsl:text>#STUB_4 RET                           * You get the picture !!&#x0A;</xsl:text>

  </xsl:element>

</xsl:template>


<xsl:template name="ConfigSignal">

     <xsl:param name="sourceSig" />
     <xsl:param name="sourcePage" />
     <xsl:param name="url" />
     <xsl:param name="con" />
     <xsl:param name="pin" />
     <xsl:param name="pan_url" />

     <xsl:for-each select="document($url)//SIGNAL/SIG_DESIG[CONNECTOR=$con][PIN=$pin]">
       <xsl:if test="../../../../FUNCTION">

  	     <xsl:text>&#x0A;</xsl:text> 

         <xsl:value-of select="$sourceSig" />
         <xsl:value-of select="../../../FN_PREFIX" />
  	     <xsl:text>,</xsl:text>
    
         <xsl:choose>
           <xsl:when test="../../../FN_NAME !=''">
  	         <xsl:value-of select="translate(../../../FN_NAME,$lcletters,$ucletters)" />
           </xsl:when>
           <xsl:otherwise>
             <xsl:text>&#x20;</xsl:text>
           </xsl:otherwise>
         </xsl:choose>
  	     <xsl:text>,</xsl:text>
 
         <xsl:choose>
           <xsl:when test="../../../FN_ADDRESS !=''">
             <xsl:text>0x0</xsl:text>
             <xsl:variable name="dhe_url" select="document($pan_url)/PAN/DHEChassisURL/URL" />
             <xsl:value-of select="document($dhe_url)/DHEChassis/DHESlot/DHEBoardURL[URL=$url]/../@address" />        
             <xsl:value-of select="../../../FN_ADDRESS" />
           </xsl:when>
           <xsl:otherwise>
             <xsl:text>&#x20;</xsl:text>
           </xsl:otherwise>
         </xsl:choose>
  	     <xsl:text>,</xsl:text>

         <xsl:choose>
           <xsl:when test="../../../FN_ELEMENTS !=''">
  	         <xsl:value-of select="../../../FN_ELEMENTS" />
           </xsl:when>
           <xsl:otherwise>
             <xsl:text>&#x20;</xsl:text>
           </xsl:otherwise>
         </xsl:choose>
  	     <xsl:text>,</xsl:text>
 	
         <xsl:text>0x</xsl:text>
         <xsl:choose>
           <xsl:when test="$sourcePage !=''">
             <xsl:value-of select="document($pan_url)/PAN/PANGUIPages/PAGE[NAME=$sourcePage]/INDEX" />
           </xsl:when>
           <xsl:otherwise>
             <xsl:variable name="disp" select="../../../FN_CONTROL/DISP_PAGE" />
             <xsl:value-of select="document($pan_url)/PAN/PANGUIPages/PAGE[NAME=$disp]/INDEX" />
           </xsl:otherwise>
         </xsl:choose>
         <xsl:text>000000</xsl:text>
  	     <xsl:text>,</xsl:text>

         <xsl:value-of select="translate(../../../FN_METHODS/SET_METHOD/METHOD/@method,$lcletters,$ucletters)"/>
  	     <xsl:text>,</xsl:text>

         <xsl:value-of select="translate(../../../FN_METHODS/GET_METHOD/METHOD/@method,$lcletters,$ucletters)"/>
         <xsl:text>,</xsl:text>

         <xsl:value-of select="translate(../../../FN_METHODS/@panType,$lcletters,$ucletters)"/>
  	     <xsl:text>,</xsl:text>

         <xsl:value-of select="translate(../../../FN_METHODS/@dheType,$lcletters,$ucletters)"/>
  	     <xsl:text>,</xsl:text>

         <xsl:choose>
           <xsl:when test="../../../FN_METHODS/SET_METHOD/METHOD/@method != 'NoMethod'">
  	         <xsl:value-of select="../../../FN_METHODS/SET_METHOD/METHOD/COEFFICIENT[1]" />
  	         <xsl:text>,</xsl:text>
  	         <xsl:value-of select="../../../FN_METHODS/SET_METHOD/METHOD/COEFFICIENT[2]" />
  	         <xsl:text>,</xsl:text>
             <xsl:value-of select="translate(../../../FN_METHODS/SET_METHOD/METHOD/@convert,$lcletters,$ucletters)"/>
  	         <xsl:text>,</xsl:text>
           </xsl:when>
           <xsl:otherwise>
  	         <xsl:value-of select="../../../FN_METHODS/GET_METHOD/METHOD/COEFFICIENT[1]" />
  	         <xsl:text>,</xsl:text>
  	         <xsl:value-of select="../../../FN_METHODS/GET_METHOD/METHOD/COEFFICIENT[2]" />
  	         <xsl:text>,</xsl:text>
             <xsl:value-of select="translate(../../../FN_METHODS/GET_METHOD/METHOD/@convert,$lcletters,$ucletters)"/>
  	         <xsl:text>,</xsl:text>
           </xsl:otherwise>
         </xsl:choose>
         
         <xsl:choose>
           <xsl:when test="../../../FN_LIMITS/MIN !=''">
  	         <xsl:value-of select="../../../FN_LIMITS/MIN" />
           </xsl:when>
           <xsl:otherwise>
             <xsl:text>&#x20;</xsl:text>
           </xsl:otherwise>
         </xsl:choose>
  	     <xsl:text>,</xsl:text>

         <xsl:choose>
           <xsl:when test="../../../FN_LIMITS/MAX !=''">
  	         <xsl:value-of select="../../../FN_LIMITS/MAX" />
           </xsl:when>
           <xsl:otherwise>
             <xsl:text>&#x20;</xsl:text>
           </xsl:otherwise>
         </xsl:choose>
  	     <xsl:text>,</xsl:text>

         <xsl:choose>
           <xsl:when test="../../../FN_METHODS/@units !='none'">
  	         <xsl:value-of select="../../../FN_METHODS/@units" />
           </xsl:when>
           <xsl:otherwise>
             <xsl:text>&#x20;</xsl:text>
           </xsl:otherwise>
         </xsl:choose>
   	     <xsl:text>,</xsl:text>

   	     <xsl:value-of select="../../../FN_HELP" />

       </xsl:if>
 	   <xsl:for-each select="document($url)//SIGNAL/SIG_DESIG[CONNECTOR=$con][PIN=$pin]/../SIG_DESTINATION">
         <xsl:if test="DEST_URL/URL">
           <xsl:call-template name="ConfigSignal">
             <xsl:with-param name="sourceSig" select="$sourceSig" />
             <xsl:with-param name="sourcePage" select="$sourcePage" />                            
             <xsl:with-param name="url" select="DEST_URL/URL" />
             <xsl:with-param name="con" select="SIGNAL/SIG_DESIG/CONNECTOR" />
             <xsl:with-param name="pin" select="SIGNAL/SIG_DESIG/PIN" />
             <xsl:with-param name="pan_url" select="$pan_url" /> 
           </xsl:call-template>
         </xsl:if>
       </xsl:for-each>
     </xsl:for-each>

</xsl:template>



<xsl:template name="FindSignal">

     <xsl:param name="sourceSig" />
     <xsl:param name="sourcePage" />
     <xsl:param name="url" />
     <xsl:param name="con" />
     <xsl:param name="pin" />
     <xsl:param name="pan_url" />
     
     <xsl:for-each select="document($url)//SIGNAL/SIG_DESIG[CONNECTOR=$con][PIN=$pin]">
       <xsl:if test="../../../@type='bitfield'"> 
         <xsl:text>DEF #</xsl:text>
         <xsl:value-of select="$sourceSig" />
         <xsl:call-template name="Tab2Col">
           <xsl:with-param name="tab" select="number('11' - string-length($sourceSig))" />
         </xsl:call-template>
         <xsl:for-each select="../../../FN_METHODS/SET_METHOD/METHOD">
           <xsl:if test="COEFFICIENT/@context='scale'">
             <xsl:text>b</xsl:text>
             <xsl:call-template name="Dec2Bin">
               <xsl:with-param name="seed"><xsl:value-of select="2147483648" /></xsl:with-param>
               <xsl:with-param name="numb"><xsl:value-of select="COEFFICIENT" /></xsl:with-param>
             </xsl:call-template>
             <xsl:text>    * Coupled to </xsl:text>
             <xsl:value-of select="translate(../../../FN_NAME,$lcletters,$ucletters)" />
           </xsl:if>
         </xsl:for-each>  
       </xsl:if>

 	   <xsl:for-each select="document($url)//SIGNAL/SIG_DESIG[CONNECTOR=$con][PIN=$pin]/../SIG_DESTINATION">
         <xsl:if test="DEST_URL/URL">
           <xsl:call-template name="FindSignal">
             <xsl:with-param name="sourceSig" select="$sourceSig" />
             <xsl:with-param name="sourcePage" select="$sourcePage" />                            
             <xsl:with-param name="url" select="DEST_URL/URL" />
             <xsl:with-param name="con" select="SIGNAL/SIG_DESIG/CONNECTOR" />
             <xsl:with-param name="pin" select="SIGNAL/SIG_DESIG/PIN" />
             <xsl:with-param name="pan_url" select="$pan_url" /> 
           </xsl:call-template>
         </xsl:if>
       </xsl:for-each>
     </xsl:for-each>

</xsl:template>

<xsl:template name="Dec2Bin">

  <xsl:param name="seed" />
  <xsl:param name="numb" />

  <xsl:choose>
    <xsl:when test="number($seed) > number($numb)">
      <xsl:text>0</xsl:text>
      <xsl:if test="$seed > 1">          
        <xsl:call-template name="Dec2Bin">
          <xsl:with-param name="seed" select="number($seed div '2')" />
          <xsl:with-param name="numb" select="$numb" />
        </xsl:call-template>
      </xsl:if>          
    </xsl:when>
    <xsl:otherwise>
      <xsl:text>1</xsl:text>
      <xsl:if test="$seed > 1">          
        <xsl:call-template name="Dec2Bin">
          <xsl:with-param name="seed" select="number($seed div '2')" />
          <xsl:with-param name="numb" select="number($numb - $seed)" />
        </xsl:call-template>
      </xsl:if>          
    </xsl:otherwise>
  </xsl:choose>
   
</xsl:template>


<xsl:template name="Tab2Col">

  <xsl:param name="tab" />

    <xsl:text> </xsl:text>
    <xsl:if test="number($tab) > number('0')">
      <xsl:call-template name="Tab2Col">
        <xsl:with-param name="tab" select="number($tab - '1')" />
      </xsl:call-template>
    </xsl:if>
</xsl:template>

<xsl:template name="UsrFlagAssig">

  <xsl:param name="pan_url" />
  
  <xsl:for-each select="document($pan_url)/PAN/PANSignals/SIGNAL">
    <xsl:variable name="signam" select="SIG_NAME" />
    <xsl:for-each select="SIG_DESTINATION">
      <xsl:if test="DEST_URL/URL">
        <xsl:if test="SIGNAL/SIG_DESIG[CONNECTOR='SEQUENCER']">          
          <xsl:if test="contains(SIGNAL/SIG_DESIG/PIN,'CMD_USER')">
            <xsl:text>DEF #</xsl:text>
            <xsl:value-of select="translate($signam,$lcletters,$ucletters)" />
            <xsl:call-template name="Tab2Col">
              <xsl:with-param name="tab" select="number('10' - string-length($signam))" />
            </xsl:call-template>
            <xsl:value-of select="number(substring(SIGNAL/SIG_DESIG/PIN,9,1)) + 12" />
            <xsl:text>&#x0A;</xsl:text>        
          </xsl:if>
        </xsl:if>          
      </xsl:if>
    </xsl:for-each>
  </xsl:for-each>

</xsl:template>

<xsl:template name="BoardAssig">

  <xsl:param name="dhe_url" />

  <xsl:text>DEF #DSLCT       x00&#x0A;</xsl:text>
  <xsl:for-each select="document($dhe_url)/DHEChassis/DHESlot">
    <xsl:if test="DHEBoardURL/URL != ''">
      <xsl:variable name="brd_url" select="DHEBoardURL/URL" />
      <xsl:variable name="brd_nam" select="document($brd_url)/DHEBoard/BoardName/NAME" />
      <xsl:text>DEF #</xsl:text>
      <xsl:value-of select="$brd_nam" />
      <xsl:call-template name="Tab2Col">
        <xsl:with-param name="tab" select="number('11' - string-length($brd_nam))" />
      </xsl:call-template>
      <xsl:text>x</xsl:text>
      <xsl:value-of select="@address" />
      <xsl:text>&#x0A;</xsl:text>        
    </xsl:if>
  </xsl:for-each>
</xsl:template>


<xsl:template name="LoopRegAssig">

  <xsl:param name="pan_url" />
  
  <xsl:for-each select="document($pan_url)/PAN/PANSignals/SIGNAL">
    <xsl:variable name="signam" select="SIG_NAME" />
    <xsl:for-each select="SIG_DESTINATION">
      <xsl:if test="DEST_URL/URL">
        <xsl:if test="SIGNAL/SIG_DESIG[CONNECTOR='SEQUENCER']">          
          <xsl:if test="contains(SIGNAL/SIG_DESIG/PIN,'LOOPREG')">
            <xsl:text>DEF #</xsl:text>
            <xsl:value-of select="translate($signam,$lcletters,$ucletters)" />
            <xsl:call-template name="Tab2Col">
              <xsl:with-param name="tab" select="number('11' - string-length($signam))" />
            </xsl:call-template>
            <xsl:variable name="str" select="string-length(substring-before(SIGNAL/SIG_DESIG/PIN,'['))" />
            <xsl:variable name="cnt" select="string-length(SIGNAL/SIG_DESIG/PIN) - 9" />           
            <xsl:value-of select="substring(SIGNAL/SIG_DESIG/PIN,$str + 2,$cnt)" />
            <xsl:text>&#x0A;</xsl:text>        
          </xsl:if>
        </xsl:if>          
      </xsl:if>
    </xsl:for-each>
  </xsl:for-each>

</xsl:template>

</xsl:stylesheet>







