<?xml version="1.0" encoding="ISO-8859-1"?>

<!-- =========================== MONSOON ================================ -->
<!-- MONSOON configuration display style sheet    (TOP LEVEL)             -->
<!-- Peter Moore 20050324                                                 -->
<!-- (c) Copyright 2004, National Optical Astronomy Observatory, which is -->
<!-- operated for the National Science Foundation by the Association of   -->
<!-- Universities for Research in Astronomy under Cooperative Agreement   -->
<!-- No. AST-0132798.                                                     -->
<!-- ==================================================================== -->

<xsl:stylesheet version = '1.0' xmlns:xsl='http://www.w3.org/1999/XSL/Transform'>

<xsl:template match="/">

  <xsl:apply-templates />

</xsl:template>

<xsl:template match="MONSOON">
      <html>
        <head>
          <title>MONSOON</title>
        </head>
        <body>
          <p/>
          <center><h2><xsl:text>Top Level MONSOON Configuration Record</xsl:text></h2></center>
          <table cellspacing="0" cellpadding="3" border="0">
            <tr>
              <td valign="center">
                <font size="+1">
                  <xsl:text>Configuration Name</xsl:text>
                </font>
              </td>
              <td>
                <table cellspacing="0" cellpadding="3" border="1" width="100%">
                  <tr>
                    <td align="center" valign="center" bgcolor="#9acd32">
                      <font size="+2">
                        <xsl:value-of select="MNSNName/NAME"/>
                      </font>
                    </td>
                  </tr>
                </table>
              </td>
            </tr>
            <tr>
              <td valign="bottom">
                <font size="+1">
                  <xsl:text>Description</xsl:text>
                </font>
              </td>
              <td valign="baseline">
                <xsl:value-of select="Description"/>
              </td>
            </tr>
          </table>

          <xsl:apply-templates select = "Documentation" />

          <xsl:apply-templates select = "RevisionHistory" />

          <xsl:apply-templates select = "MNSNSystem" />

          <xsl:apply-templates select = "MNSNSupervisor" />

          <xsl:apply-templates select = "MNSNFP" />

          <xsl:apply-templates select = "MNSNPAN" />

          <xsl:apply-templates select = "MNSNSoftware" />

          <xsl:apply-templates select = "MNSNDHEChassis" />

          <xsl:apply-templates select = "MNSNDHEBoard" />

          <xsl:apply-templates select = "MNSNDHETransition" />

        </body>
      </html>
</xsl:template>

<xsl:template match="MNSNSystem">

<!-- System Descriptions -->
      <br/>
      <font size="+1">
        <xsl:text>Available Systems (and Configuration Tools)</xsl:text>
      </font>
      <table border="1" cellpadding="2" cellspacing="0">
        <tr bgcolor="#9acd32">
          <th>System Name</th>
          <th>Supervisor Link</th>
          <th>Focal Plane Link</th>
          <th>Description</th>
        </tr>
        <xsl:for-each select="SystemURL">
          <xsl:variable name="url" select="URL" />
          <tr>
            <td>
              <xsl:element name="a">
                <xsl:attribute name="href">
                  <xsl:value-of select="$url"/>
                </xsl:attribute>
              <xsl:value-of select="document($url)/System/SystemName/NAME"/>
              </xsl:element>
            </td>
            <td align="center">
              <xsl:choose>
                <xsl:when test="document($url)/System/SupervisorURL/URL">
                  <xsl:element name="a">
                    <xsl:attribute name="href">
                      <xsl:value-of select="document($url)/System/SupervisorURL/URL"/>
                    </xsl:attribute>
                    <xsl:value-of select="document($url)/System/SupervisorURL/URL"/>
                  </xsl:element>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>Not Available</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </td>
            <td align="center">
              <xsl:choose>
                <xsl:when test="document($url)/System/FPURL/URL">
                  <xsl:element name="a">
                    <xsl:attribute name="href">
                      <xsl:value-of select="document($url)/System/FPURL/URL"/>
                    </xsl:attribute>
                    <xsl:value-of select="document($url)/System/FPURL/URL" />
                  </xsl:element>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>Not Available</xsl:text>
                </xsl:otherwise>
              </xsl:choose>  
            </td>
            <td>
              <xsl:value-of select="document($url)/System/Description"/>
            </td>
          </tr>
        </xsl:for-each>
      </table>

</xsl:template>

<xsl:template match="MNSNSupervisor">

      <br/>
      <font size="+1">
        <xsl:text>Available Supervisor Nodes</xsl:text>
      </font>
      <table border="1" cellpadding="2" cellspacing="1">
        <tr bgcolor="#9acd32">
          <th>Supervisor</th>
          <th>Network Name</th>
          <th>Attached PANs</th>
          <th>Description</th>
        </tr>
        <xsl:for-each select="SupervisorURL">
          <xsl:variable name="url" select="URL" />
          <tr>
            <td>
              <xsl:element name="a">
                <xsl:attribute name="href">
                  <xsl:value-of select="$url" />
                </xsl:attribute>  
                <xsl:value-of select="document($url)/Supervisor/SupervisorName/NAME"/>
              </xsl:element>
            </td>
            <td>
              <xsl:value-of select="document($url)/Supervisor/NetworkName/NAME"/>
            </td>
            <td>
              <table border="0" cellpadding="5" cellspacing="2">
                <tr>
                  <xsl:for-each select="document($url)/Supervisor/SupervisorPANs/PANURL">
                    <xsl:variable name="panurl" select="URL" />
                    <td>
                      <xsl:element name="a">
                        <xsl:attribute name="href">
                          <xsl:value-of select="$panurl" />
                        </xsl:attribute>  
                        <xsl:value-of select="document($panurl)/PAN/PANName/NAME"/>
                      </xsl:element>
                    </td>
                  </xsl:for-each>
                </tr>
              </table>
            </td>
            <td>
              <xsl:value-of select="document($url)/Supervisor/Description"/>
            </td>
          </tr>
        </xsl:for-each>
      </table>

</xsl:template>

<xsl:template match="MNSNFP">


      <br/>
      <font size="+1">
        <xsl:text>Available Focal Planes</xsl:text>
      </font>
      <table border="1" cellpadding="2" cellspacing="1">
        <tr bgcolor="#9acd32">
          <th>Focal Plane</th>
          <th>Attached PANs</th>
          <th>Detectors</th>
          <th>Description</th>
        </tr>
        <xsl:for-each select="FPURL">
          <xsl:variable name="url" select="URL" />
          <tr>
            <td align="center">
              <xsl:element name="a">
                <xsl:attribute name="href">
                  <xsl:value-of select="$url" />
                </xsl:attribute>  
                <xsl:value-of select="document($url)/FP/FPName/NAME"/>
              </xsl:element>
            </td>
            <td>
              <table border="0" cellpadding="5" cellspacing="2">
                <tr>
                  <xsl:for-each select="document($url)/FP/FPSegment/PANURL">
                    <xsl:variable name="panurl" select="URL" />
                    <td>
                      <xsl:element name="a">
                        <xsl:attribute name="href">
                          <xsl:value-of select="$panurl" />
                        </xsl:attribute>  
                        <xsl:value-of select="document($panurl)/PAN/PANName/NAME"/>
                      </xsl:element>
                    </td>
                  </xsl:for-each>
                </tr>
              </table>
            </td>
            <td>
              <table border="0" cellpadding="5" cellspacing="2">
                  <xsl:for-each select="document($url)/FP/FPSegment/FPGeometry/Detector">
                <tr>
                    <td align="center">
                      <xsl:value-of select="DetectorName/NAME"/>
                    </td>
                </tr>
                  </xsl:for-each>
              </table>
            </td>
            <td align="left">
              <xsl:value-of select="document($url)/FP/Description"/>
            </td>
          </tr>
        </xsl:for-each>
      </table>

</xsl:template>

<xsl:template match="MNSNPAN">

      <br/>
      <font size="+1">
        <xsl:text>Available PAN Nodes</xsl:text>
      </font>
      <table border="1" cellpadding="2" cellspacing="1">
        <tr bgcolor="#9acd32">
          <th>PAN</th>
          <th>Network Name</th>
          <th>Software Version</th>
          <th>Attached DHE</th>
          <th>Description</th>
        </tr>
        <xsl:for-each select="PANURL">
          <xsl:variable name="url" select="URL" />
          <tr>
            <td align="center">
              <xsl:element name="a">
                <xsl:attribute name="href">
                  <xsl:value-of select="$url" />
                </xsl:attribute>  
                <xsl:value-of select="document($url)/PAN/PANName/NAME"/>
              </xsl:element>
            </td>
            <td align="center">
              <xsl:value-of select="document($url)/PAN/NetworkName/NAME"/>
            </td>
            <td align="center">
              <xsl:variable name="sw" select="document($url)/PAN/SoftwareURL/URL" />
              <xsl:element name="a">
                <xsl:attribute name="href">
                  <xsl:value-of select="$sw" />
                </xsl:attribute>  
                <xsl:value-of select="document($sw)/Software/SoftwareName/NAME"/>             
              </xsl:element>
            </td>
            <td align="center">
              <xsl:choose>
                <xsl:when test="document($url)/PAN/DHEChassisURL/URL">                   
                  <xsl:variable name="dheurl" select="document($url)/PAN/DHEChassisURL/URL" />
                  <xsl:element name="a">
                    <xsl:attribute name="href">
                      <xsl:value-of select="$dheurl" />
                    </xsl:attribute>  
                    <xsl:value-of select="document($dheurl)/DHEChassis/DHEName/NAME"/>
                  </xsl:element>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>Not Attached</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </td>
            <td align="left">
              <xsl:value-of select="document($url)/PAN/Description"/>
            </td>
          </tr>
        </xsl:for-each>
      </table>

</xsl:template>

<xsl:template match="MNSNSoftware">

      <br/>
      <font size="+1">
        <xsl:text>Available Software Versions</xsl:text>
      </font>
      <table border="1" cellpadding="2" cellspacing="1">
        <tr bgcolor="#9acd32">
          <th>Version Name</th>
          <th>Description</th>
        </tr>
        <xsl:for-each select="SoftwareURL">
          <xsl:variable name="url" select="URL" />
          <tr>
            <td align="center">
              <xsl:element name="a">
                <xsl:attribute name="href">
                  <xsl:value-of select="$url" />
                </xsl:attribute>  
                <xsl:value-of select="document($url)/Software/SoftwareName/NAME"/>
              </xsl:element>
            </td>
            <td align="left">
              <xsl:value-of select="document($url)/Software/Description"/>
            </td>
          </tr>
        </xsl:for-each>
      </table>

</xsl:template>

<xsl:template match="MNSNDHEChassis">

      <br/>
      <font size="+1">
        <xsl:text>Available DHE Chassis</xsl:text>
      </font>
      <table border="1" cellpadding="2" cellspacing="1">
        <tr bgcolor="#9acd32">
          <th>DHE Name</th>
          <th>Size</th>
          <th>Master</th>
          <th>Description</th>
        </tr>
        <xsl:for-each select="DHEChassisURL">
          <xsl:variable name="url" select="URL" />
          <tr>
            <td align="center">
              <xsl:element name="a">
                <xsl:attribute name="href">
                  <xsl:value-of select="$url" />
                </xsl:attribute>  
                <xsl:value-of select="document($url)/DHEChassis/DHEName/NAME"/>
              </xsl:element>
            </td>
            <td align="center">
              <xsl:value-of select="document($url)/DHEChassis/@slots"/>
              <xsl:text> Slots</xsl:text>              
            </td>
            <td align="center">
              <xsl:choose>
                <xsl:when test="document($url)/DHEChassis/DHEMaster/@master='true'">
                  <xsl:text>Yes</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>No</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </td>
            <td align="left">
              <xsl:value-of select="document($url)/DHEChassis/Description"/>
            </td>
          </tr>
        </xsl:for-each>
      </table>

</xsl:template>

<xsl:template match="MNSNDHEBoard">

      <br/>
      <font size="+1">
        <xsl:text>Available DHE Boards</xsl:text>
      </font>
      <table border="1" cellpadding="2" cellspacing="1">
        <tr bgcolor="#9acd32">
          <th>Board Name</th>
          <th>Board Code</th>
          <th>FP Serial Number</th>
          <th>Silicon Serial Number</th>
          <th>Firmware Version</th>
          <th>Description</th>
        </tr>
        <xsl:for-each select="DHEBoardURL">
          <xsl:variable name="url" select="URL" />
          <tr>
            <td align="center">
              <xsl:element name="a">
                <xsl:attribute name="href">
                  <xsl:value-of select="$url" />
                </xsl:attribute>  
                <xsl:value-of select="document($url)/DHEBoard/BoardName/NAME"/>
              </xsl:element>
            </td>
            <td align="center">
              <xsl:value-of select="document($url)/DHEBoard/BoardIdentity"/>
            </td>
            <td align="center">
              <xsl:value-of select="document($url)/DHEBoard/BoardSerialNumber"/>
            </td>
            <td align="center">
              <xsl:value-of select="document($url)/DHEBoard/BoardSiliconNumber"/>
            </td>
            <td align="center">
              <xsl:value-of select="document($url)/DHEBoard/Firmware/VERSION"/>
            </td>
            <td align="left">
              <xsl:value-of select="document($url)/DHEBoard/Description"/>
            </td>
          </tr>
        </xsl:for-each>
      </table>

</xsl:template>

<xsl:template match="MNSNDHETransition">


      <br/>
      <font size="+1">
        <xsl:text>Available DHE Transition Boards</xsl:text>
      </font>
      <table border="1" cellpadding="2" cellspacing="1">
        <tr bgcolor="#9acd32">
          <th>Board Name</th>
          <th>Board Code</th>
          <th>Serial Number</th>
          <th>Description</th>
        </tr>
        <xsl:for-each select="DHETransitionURL">
          <xsl:variable name="url" select="URL" />
          <tr>
            <td align="center">
              <xsl:element name="a">
                <xsl:attribute name="href">
                  <xsl:value-of select="$url" />
                </xsl:attribute>  
                <xsl:value-of select="document($url)/DHETransition/BoardName/NAME"/>
              </xsl:element>
            </td>
            <td align="center">
              <xsl:value-of select="document($url)/DHETransition/BoardIdentity"/>
            </td>
            <td align="center">
              <xsl:value-of select="document($url)/DHETransition/BoardSerialNumber"/>
            </td>
            <td align="left">
              <xsl:value-of select="document($url)/DHETransition/Description"/>
            </td>
          </tr>
        </xsl:for-each>
      </table>

</xsl:template>

<xsl:template match="System">

    <html>
      <head>
        <title>System</title>
      </head>
      <body>
        <p/>
        <center>
          <h2>
            <xsl:text>System Description Record</xsl:text>
          </h2>
        </center>
        <table cellspacing="0" cellpadding="3" border="0">
          <tr>
            <td valign="center">
              <font size="+1">
                <xsl:text>System Name</xsl:text>
              </font>
            </td>
            <td>
              <table cellspacing="0" cellpadding="3" border="1" width="100%">
                <tr>
                  <td align="center" valign="center" bgcolor="#9acd32">
                    <font size="+2">
                      <xsl:value-of select="SystemName/NAME"/>
                    </font>
                  </td>
                </tr>
              </table>
            </td>
          </tr>
          <tr>
            <td valign="bottom">
              <font size="+1">
                <xsl:text>Description</xsl:text>
              </font>
            </td>
            <td valign="baseline">
              <xsl:value-of select="Description"/>
            </td>
          </tr>
          <tr>
            <xsl:choose>
              <xsl:when test="SupervisorURL/URL">
                <td valign="bottom">
                  <font size="+1">
                    <xsl:text>Supervisor Node</xsl:text>  
                  </font>
                </td>
                <td valign="baseline">
                  <xsl:variable name="surl" select="SupervisorURL/URL" />
                  <xsl:element name="a">
                    <xsl:attribute name="href">
                      <xsl:value-of select="$surl"/>
                    </xsl:attribute>
                    <xsl:value-of select="document($surl)/Supervisor/SupervisorName/NAME"/>
                  </xsl:element>
                </td>
              </xsl:when>

              <xsl:otherwise>
                <td valign="bottom">
                  <font size="+1">
                    <xsl:text>PAN Node</xsl:text>  
                  </font>
                </td>
                <td valign="baseline">
                  <xsl:variable name="purl" select="PANURL/URL" />
                  <xsl:element name="a">
                    <xsl:attribute name="href">
                      <xsl:value-of select="$purl"/>
                    </xsl:attribute>
                    <xsl:value-of select="document($purl)/PAN/PANName/NAME"/>
                  </xsl:element>
                  <xsl:text> ( -- </xsl:text>
                  <xsl:element name="a">
                    <xsl:attribute name="href">
                      <xsl:text>CSV_</xsl:text>
                      <xsl:value-of select="SystemName/NAME" />
                      <xsl:text>.xml</xsl:text>
                    </xsl:attribute>
                  <xsl:text>Generate configuration files for System by clicking here</xsl:text>
                </xsl:element>
                <xsl:text> -- )</xsl:text>
                </td>
              </xsl:otherwise>
            </xsl:choose>
          </tr>

          <tr>
            <td valign="bottom">
              <font size="+1">
                <xsl:text>Focal Plane</xsl:text>
              </font>
            </td>
            <td valign="baseline">
              <xsl:variable name="furl" select="FPURL/URL" />
              <xsl:element name="a">
                <xsl:attribute name="href">
                  <xsl:value-of select="$furl"/>
                </xsl:attribute>
                <xsl:value-of select="document($furl)/FP/FPName/NAME"/>
              </xsl:element>
            </td>           
          </tr>
        </table>

        <xsl:apply-templates select = "Documentation" />

        <xsl:apply-templates select = "RevisionHistory" />
        
      </body>
    </html>

</xsl:template>



<xsl:template match="FP">
      <html>
        <head>
          <title>Focal Plane</title>
        </head>
        <body>
          <p/><h2><xsl:text>Focal Plane Description Record</xsl:text></h2>
          <table cellspacing="0" cellpadding="3" border="0">
            <tr>
              <td valign="center">
                <font size="+1">
                  <xsl:text>Focal Plane Name</xsl:text>
                </font>
              </td>
              <td>
                <table cellspacing="0" cellpadding="3" border="1" width="100%">
                  <tr>
                    <td align="center" valign="center" bgcolor="#9acd32">
                      <font size="+2">
                        <xsl:value-of select="FPName/NAME"/>
                      </font>
                    </td>
                  </tr>
                </table>
              </td>
            </tr>
            <tr>
              <td valign="bottom"><h3><xsl:text>Description</xsl:text></h3></td>
              <td valign="baseline"><xsl:value-of select="Description"/></td>
            </tr>
          </table>

          <xsl:apply-templates select = "Documentation" />

          <xsl:apply-templates select = "RevisionHistory" />

          <xsl:apply-templates select = "FPSegment" />

          <xsl:apply-templates select = "FPSegment/FPGeometry/Detector" />
        </body>
      </html>
</xsl:template>



<xsl:template match="FPSegment">
  <xsl:variable name="pan_url" select="PANURL/URL" />
      <xsl:for-each select="FPGeometry">
        <p />
        <table border="1" cellspacing="0" cellpadding="1">
          <caption>
              <xsl:text>Detector assignments to PAN Node </xsl:text>
              <xsl:element name="a">
                <xsl:attribute name="href">
                  <xsl:value-of select="$pan_url"/>
                </xsl:attribute>
                <xsl:value-of select="document($pan_url)/PAN/PANName/NAME" />
              </xsl:element>
              <xsl:text> and DHE node </xsl:text>
              <xsl:variable name="dhe_url" select="document($pan_url)/PAN/DHEChassisURL/URL" />
              <xsl:element name="a">
                <xsl:attribute name="href">
                  <xsl:value-of select="$dhe_url"/>
                </xsl:attribute>
                <xsl:value-of select="document($dhe_url)/DHEChassis/DHEName/NAME"/>
              </xsl:element>
          </caption>
          <th bgcolor="#9acd32">Detector Name</th>
          <th bgcolor="#9acd32">Detector Type</th>
          <th bgcolor="#9acd32">Serial Number</th>
          <th bgcolor="#9acd32">Global Origin</th>
          <th bgcolor="#9acd32">Detector Size</th>
          <th bgcolor="#9acd32">Active Origin</th>
          <th bgcolor="#9acd32">Active Size  </th>
          <th bgcolor="#9acd32">Pixel Size   </th>
          <th bgcolor="#9acd32">Detector Notes</th>
          <th bgcolor="#9acd32">Test Data Link</th>
          <xsl:for-each select="Detector">
            <tr>
              <td align="center"><xsl:value-of select="DetectorName/NAME"/></td>
              <td align="center"><xsl:value-of select="DetectorType"/></td>
              <td align="center"><xsl:value-of select="DetectorSerialNum"/></td>
      		  <td align="center">
      		    <table border="0" cellspacing="0" cellpadding="1">
                  <tr>
                    <td width="20%" align="left"><xsl:text>X:</xsl:text></td>
                    <td align="right"><xsl:value-of select="DetectorFPOrigin/DIMENSION/XSIZE"/></td>
                    <td width="20%" align="center"><xsl:value-of select="DetectorFPOrigin/DIMENSION/@units"/></td>
                  </tr>
                  <tr>
                    <td width="20%" align="left"><xsl:text>Y:</xsl:text></td>
                    <td align="right"><xsl:value-of select="DetectorFPOrigin/DIMENSION/YSIZE"/></td>
                    <td width="20%" align="center"><xsl:value-of select="DetectorFPOrigin/DIMENSION/@units"/></td>
                  </tr>
                </table>
              </td>
      		  <td align="center">
      		    <table border="0" cellspacing="0" cellpadding="1">
                  <tr>
                    <td width="20%" align="left"><xsl:text>X:</xsl:text></td>
                    <td align="right"><xsl:value-of select="DetectorSize/DIMENSION/XSIZE"/></td>
                    <td width="20%" align="center"><xsl:value-of select="DetectorSize/DIMENSION/@units"/></td>
                  </tr>
                  <tr>
                    <td width="20%" align="left"><xsl:text>Y:</xsl:text></td>
                    <td align="right"><xsl:value-of select="DetectorSize/DIMENSION/YSIZE"/></td>
                    <td width="20%" align="center"><xsl:value-of select="DetectorSize/DIMENSION/@units"/></td>
                  </tr>
                </table>
              </td>
              <td align="center">
      		    <table border="0" cellspacing="0" cellpadding="1">
                  <tr>
                    <td width="20%" align="left"><xsl:text>X:</xsl:text></td>
                    <td align="right"><xsl:value-of select="DetectorActiveOrigin/DIMENSION/XSIZE"/></td>
                    <td width="20%" align="center"><xsl:value-of select="DetectorActiveOrigin/DIMENSION/@units"/></td>
                  </tr>
                  <tr>
                    <td width="20%" align="left"><xsl:text>Y:</xsl:text></td>
                    <td align="right"><xsl:value-of select="DetectorActiveOrigin/DIMENSION/YSIZE"/></td>
                    <td width="20%" align="center"><xsl:value-of select="DetectorActiveOrigin/DIMENSION/@units"/></td>
                  </tr>
                </table>
              </td>
              <td align="center">
      		    <table border="0" cellspacing="0" cellpadding="1">
                  <tr>
                    <td width="20%" align="left"><xsl:text>X:</xsl:text></td>
                    <td align="right"><xsl:value-of select="DetectorActiveSize/DIMENSION/XSIZE"/></td>
                    <td width="20%" align="center"><xsl:value-of select="DetectorActiveSize/DIMENSION/@units"/></td>
                  </tr>
                  <tr>
                    <td width="20%" align="left"><xsl:text>Y:</xsl:text></td>
                    <td align="right"><xsl:value-of select="DetectorActiveSize/DIMENSION/YSIZE"/></td>
                    <td width="20%" align="center"><xsl:value-of select="DetectorActiveSize/DIMENSION/@units"/></td>
                  </tr>
                </table>
              </td>
      		  <td align="center">
                <table border="0" cellspacing="0" cellpadding="1">
                  <tr>
                    <td width="20%" align="left"><xsl:text>X:</xsl:text></td>
                    <td align="right"><xsl:value-of select="DetectorPixelSize/DIMENSION/XSIZE"/></td>
                    <td width="20%" align="center"><xsl:value-of select="DetectorPixelSize/DIMENSION/@units"/></td>
                  </tr>
                  <tr>
                    <td width="20%" align="left"><xsl:text>Y:</xsl:text></td>
                    <td align="right"><xsl:value-of select="DetectorPixelSize/DIMENSION/YSIZE"/></td>
                    <td width="20%" align="center"><xsl:value-of select="DetectorPixelSize/DIMENSION/@units"/></td>
                  </tr>
                </table>
              </td>
              <td width="30%">
                <table border="0" cellspacing="0" cellpadding="1">
                  <xsl:for-each select="DetectorNotes/NOTE">
                    <tr>
                      <td>
                        <xsl:value-of select="." />
                      </td>
                    </tr>
                  </xsl:for-each>
                </table>   
              </td>
              <td width="7%" align="center">
                <xsl:choose>
                  <xsl:when test="DetectorTestRecordURL/URL">
                    <xsl:element name="a">
                      <xsl:attribute name="href">
                        <xsl:value-of select="DetectorTestRecordURL/URL"/>
                      </xsl:attribute>
                      <xsl:value-of select="DetectorName/NAME"/>
                    </xsl:element>
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:text>Not Available</xsl:text>
                  </xsl:otherwise>
                </xsl:choose>
              </td>
            </tr>            
          </xsl:for-each>
        </table>
      </xsl:for-each>

</xsl:template>


<xsl:template match="Detector">
      <p />
      <table border="1" cellspacing="0" cellpadding="1">
        <tr>
          <td align="center" bgcolor="#9acd32">
            <xsl:text>Detector Signals</xsl:text>
          </td>
          <td align="center" bgcolor="#9acd32">
            <xsl:text>Detector Signal Paths for </xsl:text><xsl:value-of select="DetectorName/NAME"/>
            <xsl:text> (</xsl:text>
            <font color="#0000FF"><xsl:text>Board Name - </xsl:text></font>
            <font color="#000000"><xsl:text>Connector - </xsl:text></font>
            <font color="#FF0000"><xsl:text>Signal Name - </xsl:text></font>
            <font color="#308020"><xsl:text>(Signal Type) - </xsl:text></font>
            <font color="#8000FF"><xsl:text>Function Name - </xsl:text></font>
            <font color="#FF0080"><xsl:text>Attribute Name</xsl:text></font>
            <xsl:text>)</xsl:text>
            
          </td>
        </tr>
              <xsl:for-each select="DetectorSignals/SIGNAL">
                <tr>
                  <td align="center">
                    <font color="FF0000">
                      <xsl:value-of select="SIG_NAME"/>
                    </font>
                    <font color="308020">
                      <xsl:text> (</xsl:text>
                      <xsl:value-of select="@type"/>
                      <xsl:text>)</xsl:text>
                    </font>
	              </td>
	              <td>
	                <xsl:for-each select="SIG_DESTINATION">
                      <xsl:if test="DEST_URL/URL">
                        <table cellspacing="0" cellpadding="2" border="0">
                          <tr>
                            <xsl:call-template name="SIGNAL">
                              <xsl:with-param name="sourceSig" select="../SIG_NAME" />                            
                              <xsl:with-param name="url" select="DEST_URL/URL" />
                              <xsl:with-param name="con" select="SIGNAL/SIG_DESIG/CONNECTOR" />
                              <xsl:with-param name="pin" select="SIGNAL/SIG_DESIG/PIN" />
                              <xsl:with-param name="mode" select="../@type" />
                            </xsl:call-template>
                          </tr>
                        </table>
                      </xsl:if>
                    </xsl:for-each>
                  </td>
                </tr>
              </xsl:for-each>
      </table>
</xsl:template>

<xsl:template name="SIGNAL">

     <xsl:param name="sourceSig" />
     <xsl:param name="url" />
     <xsl:param name="con" />
     <xsl:param name="pin" />
     <xsl:param name="mode" />
     
     <td align="left"> <!-- width="10"> -->
       <font color="#0000FF"><xsl:text>=></xsl:text></font>
     </td>
     <td align="left"> <!-- width="110"> -->
       <xsl:element name="a">
         <xsl:attribute name="href">
           <xsl:value-of select="$url"/>
         </xsl:attribute>
         <xsl:value-of select="document($url)//NAME" />
       </xsl:element>
     </td>
     <td align="left">
       <table cellspacing="2" cellpadding="0" border="0">
 	     <xsl:for-each select="document($url)//SIGNAL/SIG_DESIG[CONNECTOR=$con][PIN=$pin]">
           <tr>

 <xsl:if test="$mode != 'logical'">
             <td align="left"> <!-- width="70"> -->
               <xsl:value-of select="CONNECTOR"/>
               <xsl:text>:</xsl:text>
               <xsl:value-of select="PIN"/>
             </td>
             <td align="left"> <!-- width="120"> -->
               <font color="FF0000">
                 <xsl:value-of select="../SIG_NAME"/>
               </font>
             </td>
             <td align="left"> <!-- width="70"> -->
               <font color="308020">
                 <xsl:text>(</xsl:text>
                 <xsl:value-of select="../@type"/>
                 <xsl:text>)</xsl:text>
               </font>
             </td>
 </xsl:if>
 
               <xsl:if test="../../../../FUNCTION">
                 <xsl:if test="../../../FN_NAME !=''">
                   <td align="left"> <!-- width="10"> -->
                     <font color="#0000FF"><xsl:text>=></xsl:text></font>
                   </td>
                   <td align="left"> <!-- width="120"> -->
                     <font color="#8000FF">
                       <xsl:value-of select="../../../FN_NAME"/>
                     </font>
                   </td>
                 </xsl:if>
                 <td align="left"> <!-- width="10"> -->
                   <font color="#0000FF"><xsl:text>=></xsl:text></font>
                 </td>
                 <td align="left"> <!-- width="120"> -->
                   <font color="#FF0080">
                     <xsl:value-of select="$sourceSig" />
                     <xsl:value-of select="../../../FN_PREFIX" />
                   </font>
                 </td>
<xsl:if test="$mode = 'logical'">
                 <td>
                   <xsl:text> - </xsl:text>
                   <xsl:value-of select="../../../FN_HELP" />
                 </td>
</xsl:if>
               </xsl:if>
             <td align="left">
               <table cellspacing="0" cellpadding="2" border="0">
 	             <xsl:for-each select="document($url)//SIGNAL/SIG_DESIG[CONNECTOR=$con][PIN=$pin]/../SIG_DESTINATION">
                   <xsl:choose>
                     <xsl:when test="DEST_URL/URL">
                       <tr> 
                         <xsl:call-template name="SIGNAL">
                           <xsl:with-param name="sourceSig" select="$sourceSig" />
                           <xsl:with-param name="url" select="DEST_URL/URL" />
                           <xsl:with-param name="con" select="SIGNAL/SIG_DESIG/CONNECTOR" />
                           <xsl:with-param name="pin" select="SIGNAL/SIG_DESIG/PIN" />
                           <xsl:with-param name="mode" select="$mode" />
                         </xsl:call-template>
                       </tr>
                     </xsl:when>
                     <xsl:otherwise>

<xsl:if test="$mode !=' logical'">
 
                       <tr>
                         <td align="left"> <!-- width="10"> -->
                           <font color="#0000FF">
                             <xsl:text>=></xsl:text>
                           </font>
                         </td>
                         <td align="left"> <!-- width="150"> -->
                           <font color="FF0000">
                             <xsl:value-of select="SIGNAL/SIG_NAME"/>
                           </font>
                         </td>
                         <td align="left"> <!-- width="50"> -->
                           <xsl:value-of select="SIGNAL/SIG_DESIG/CONNECTOR" />
                           <xsl:text>:</xsl:text>
                           <xsl:value-of select="SIGNAL/SIG_DESIG/PIN" />
                         </td>
                       </tr>

</xsl:if>

                     </xsl:otherwise>
                   </xsl:choose>
                 </xsl:for-each>
               </table>
             </td>
           </tr>
         </xsl:for-each>
       </table>
     </td>

</xsl:template>

<xsl:template match="Supervisor">
      <html>
        <head>
          <title>Supervisor</title>
        </head>
        <body>
          <p/>
          <center><h2><xsl:text>Supervisor Configuration Record</xsl:text></h2></center>
          <table cellspacing="0" cellpadding="3" border="0">
            <tr>
              <td valign="center">
                <font size="+1">
                  <xsl:text>Supervisor Name</xsl:text>
                </font>
              </td>
              <td>
                <table cellspacing="0" cellpadding="3" border="1" width="100%">
                  <tr>
                    <td align="center" valign="center" bgcolor="#9acd32">
                      <font size="+2">
                        <xsl:value-of select="SupervisorName/NAME"/>
                      </font>
                    </td>
                  </tr>
                </table>
              </td>
            </tr>
            <tr>
              <td valign="bottom">
                <font size="+1">
                  <xsl:text>Description</xsl:text>
                </font>
              </td>
              <td valign="baseline">
                <xsl:value-of select="Description"/>
              </td>
            </tr>
            <tr>
              <td valign="bottom">
                <font size="+1">
                  <xsl:text>Network Name</xsl:text>
                </font>
              </td>
              <td valign="baseline">
                <xsl:value-of select="NetworkName/NAME"/>
              </td>
            </tr>
          </table>

          <xsl:apply-templates select = "Documentation" />

          <xsl:apply-templates select = "RevisionHistory" />

          <xsl:apply-templates select = "SupervisorPANs" />

        </body>
      </html>
</xsl:template>

<xsl:template match="SupervisorPANs">

<!-- System Descriptions -->
      <br/><h2>PAN Nodes</h2>
      <table border="1" cellpadding="2" cellspacing="0">
        <tr bgcolor="#9acd32">
          <th>PAN Name</th>
          <th>Description</th>
          <th>Link</th>
        </tr>
        <xsl:for-each select="PANURL">
          <xsl:variable name="url" select="URL" />
          <tr>
            <td>
              <xsl:value-of select="document($url)/PAN/PANName/NAME"/>
            </td>
            <td>
              <xsl:value-of select="document($url)/PAN/Description"/>
            </td>
            <td>
              <xsl:element name="a">
                <xsl:attribute name="href">
                  <xsl:value-of select="$url"/>
                </xsl:attribute>
                <xsl:value-of select="$url" />
              </xsl:element>
            </td>
          </tr>
        </xsl:for-each>
      </table>

</xsl:template>

<xsl:template match="PAN">
  <html>
  <head>
      <title>PAN Computer</title>
  </head>
    <body>
      <p/><h2><xsl:text>PAN Computer Description Record</xsl:text></h2>
      <table cellspacing="0" cellpadding="3" border="0">
        <tr>
          <td valign="center">
            <font size="+1">
              <xsl:text>PAN Name</xsl:text>
            </font>
          </td>
          <td>
            <table cellspacing="0" cellpadding="3" border="1" width="100%">
              <tr>
                <td align="center" valign="center" bgcolor="#9acd32">
                  <font size="+2">
                    <xsl:value-of select="PANName/NAME"/>
                  </font>
                </td>
              </tr>
            </table>
          </td>
        </tr>
        <tr>
          <td valign="bottom"><font size="+1"><xsl:text>Description</xsl:text></font></td>
          <td valign="baseline"><xsl:value-of select="Description"/></td>
        </tr>
        <tr>
          <td valign="bottom"><font size="+1"><xsl:text>Network Name</xsl:text></font></td>
          <td valign="baseline"><xsl:value-of select="NetworkName/NAME"/></td>
        </tr>

        <tr>
          <td valign="bottom"><font size="+1"><xsl:text>Software Suite</xsl:text></font></td>
          <td valign="baseline">
            <xsl:variable name="sw" select="SoftwareURL/URL" />
            <xsl:text> </xsl:text>
            <xsl:element name="a">
              <xsl:attribute name="href">
                <xsl:value-of select="SoftwareURL/URL"/>
              </xsl:attribute>
              <xsl:value-of select="document($sw)/Software/SoftwareName/NAME" />
            </xsl:element>
          </td>
        </tr>


        <tr>
          <td valign="bottom"><font size="+1"><xsl:text>DHE Name</xsl:text></font></td>
          <td valign="baseline">
            <xsl:variable name="dhe" select="DHEChassisURL/URL" />
            <xsl:element name="a">
              <xsl:attribute name="href">
                <xsl:value-of select="DHEChassisURL/URL"/>
              </xsl:attribute>
              <xsl:value-of select="document($dhe)/DHEChassis/DHEName/NAME"/>
            </xsl:element>
          </td>
        </tr>
     </table>

     <xsl:apply-templates select = "Documentation" />

     <xsl:apply-templates select = "RevisionHistory" />

<!-- Show the local attribute list -->
     <br />
     <font size="+1">
       <xsl:text>Local PAN Attributes</xsl:text>
     </font>
     <table border="1" cellspacing="0" cellpadding="1">
       <tr>
         <td align="center" bgcolor="#9acd32">
           <xsl:text>PAN signal</xsl:text>
         </td>
         <td align="center" bgcolor="#9acd32">
           <xsl:text>Description</xsl:text>
         </td>
         <td align="center" bgcolor="#9acd32">
           <xsl:text>Signal - Function - Attribute linkage</xsl:text>
           <xsl:text> (</xsl:text>
           <font color="#0000FF"><xsl:text>Board Name => </xsl:text></font>
           <font color="#8000FF"><xsl:text>Function Name => </xsl:text></font>
           <font color="#FF0080"><xsl:text>Attribute Name</xsl:text></font>
           <xsl:text>)</xsl:text>        
         </td>
       </tr>
       <xsl:for-each select="PANSignals/SIGNAL">
         <tr>
           <td align="center">
             <font color="FF0000">
               <xsl:value-of select="SIG_NAME"/>
             </font>
      	   </td>
           <td align="center">
             <font color="000000">
               <xsl:value-of select="SIG_DESCRIPTION"/>
             </font>
      	   </td>
	       <td>
	         <xsl:for-each select="SIG_DESTINATION">
               <xsl:if test="DEST_URL/URL">
                 <table cellspacing="0" cellpadding="2" border="0">
                   <tr>
                     <xsl:call-template name="SIGNAL">
                       <xsl:with-param name="sourceSig" select="../SIG_NAME" />                            
                       <xsl:with-param name="url" select="DEST_URL/URL" />
                       <xsl:with-param name="con" select="SIGNAL/SIG_DESIG/CONNECTOR" />
                       <xsl:with-param name="pin" select="SIGNAL/SIG_DESIG/PIN" />
                       <xsl:with-param name="mode" select="../@type" />
                     </xsl:call-template>
                   </tr>
                 </table>
               </xsl:if>
             </xsl:for-each>
           </td>
         </tr>
       </xsl:for-each>
     </table>

<!-- Show the Mode list -->

    </body>
  </html>
</xsl:template>





<xsl:template match="Software">
  <html>
  <head>
      <title>Software</title>
  </head>
    <body>
      <p/><h2><xsl:text>Software Description Record</xsl:text></h2>
      <table cellspacing="0" cellpadding="3" border="0">
        <tr>
          <td valign="center">
            <font size="+1">
              <xsl:text>Software Name</xsl:text>
            </font>
          </td>
          <td>
            <table cellspacing="0" cellpadding="3" border="1" width="100%">
              <tr>
                <td align="center" valign="center" bgcolor="#9acd32">
                  <font size="+2">
                    <xsl:value-of select="SoftwareName/NAME"/>
                  </font>
                </td>
              </tr>
            </table>
          </td>
        </tr>
        <tr>
          <td valign="bottom"><font size="+1"><xsl:text>Description</xsl:text></font></td>
          <td valign="baseline"><xsl:value-of select="Description"/></td>
        </tr>
      </table>

     <xsl:apply-templates select = "Documentation" />

     <xsl:apply-templates select = "RevisionHistory" />

<!-- Show the local attribute list -->
     <br />
     <font size="+1">
       <xsl:text>Local Software Attributes</xsl:text>
     </font>
     <table border="1" cellspacing="0" cellpadding="1">
       <tr>
         <td align="center" bgcolor="#9acd32">
           <xsl:text>Software signal</xsl:text>
         </td>
         <td align="center" bgcolor="#9acd32">
           <xsl:text>Description</xsl:text>
         </td>
         <td align="center" bgcolor="#9acd32">
           <xsl:text>Signal - Function - Attribute linkage</xsl:text>
           <xsl:text> (</xsl:text>
           <font color="#0000FF"><xsl:text>Board Name => </xsl:text></font>
           <font color="#8000FF"><xsl:text>Function Name => </xsl:text></font>
           <font color="#FF0080"><xsl:text>Attribute Name</xsl:text></font>
           <xsl:text>)</xsl:text>        
         </td>
       </tr>
       <xsl:for-each select="SoftwareSignals/SIGNAL">
         <tr>
           <td align="center">
             <font color="FF0000">
               <xsl:value-of select="SIG_NAME"/>
             </font>
      	   </td>
           <td align="center">
             <font color="000000">
               <xsl:value-of select="SIG_DESCRIPTION"/>
             </font>
      	   </td>


	       <td>
	         <xsl:for-each select="SIG_DESTINATION">
               <xsl:if test="DEST_URL/URL">
                 <table cellspacing="0" cellpadding="2" border="0">
                   <tr>
                     <xsl:call-template name="SIGNAL">
                       <xsl:with-param name="sourceSig" select="../SIG_NAME" />                            
                       <xsl:with-param name="url" select="DEST_URL/URL" />
                       <xsl:with-param name="con" select="SIGNAL/SIG_DESIG/CONNECTOR" />
                       <xsl:with-param name="pin" select="SIGNAL/SIG_DESIG/PIN" />
                       <xsl:with-param name="mode" select="../@type" />
                     </xsl:call-template>
                   </tr>
                 </table>
               </xsl:if>
             </xsl:for-each>
           </td>
         </tr>
       </xsl:for-each>
     </table>
    </body>
  </html>
</xsl:template>

<xsl:template match="DHEChassis">

  <html>
  <head>
      <title>DHEChassis</title>
  </head>
  <body>
      <p/><h2><xsl:text>DHE Chassis Description Record</xsl:text></h2>
      <table cellspacing="0" cellpadding="3" border="0">
        <tr>
          <td valign="center">
            <font size="+1">
              <xsl:text>DHE Chassis Name</xsl:text>
            </font>
          </td>
          <td>
            <table cellspacing="0" cellpadding="3" border="1" width="100%">
              <tr>
                <td align="center" valign="center" bgcolor="#9acd32">
                  <font size="+2">
                    <xsl:value-of select="DHEName/NAME"/>
			        <xsl:if test="DHEMaster/@master = 'true'">
  				      <xsl:text> - (MASTER)</xsl:text>
			        </xsl:if>            
  				  </font>
                </td>
              </tr>
            </table>
          </td>
        </tr>
        <tr>
          <td valign="bottom">
            <font size="+1">
              <xsl:text>Description</xsl:text>
            </font>
          </td>
          <td valign="baseline">
            <xsl:value-of select="Description"/>
          </td>
        </tr>
      </table>

     <xsl:apply-templates select = "Documentation" />

     <xsl:apply-templates select = "RevisionHistory" />

      <br/><h2>Chassis Front Slot Stuffing Table</h2>

      <table border="1" cellspacing="1" cellpadding="0">
        <tr bgcolor="#9acd32">
          <th>Slot Number</th>
          <th>Function Board Type</th>
          <th>Identity Code</th>
          <th>Serial Number</th>
          <th>DheBoard Suffix</th>
          <th>File Name</th>
        </tr>
        <xsl:for-each select="DHESlot">
          <xsl:variable name="Board" select="DHEBoardURL/URL" />
          <tr>
            <td align="center"><xsl:value-of select="@position"/></td>
            <td align="left">
              <xsl:value-of select="document($Board)/DHEBoard/BoardName/NAME"/>
            </td>
            <td align="center">
              <xsl:value-of select="document($Board)/DHEBoard/BoardIdentity"/>
            </td>
            <td align="center">
              <xsl:value-of select="document($Board)/DHEBoard/BoardSerialNumber"/>
            </td>
            <td align="center">
              <xsl:value-of select="SlotSuffix"/>
            </td>
            <td align="left">
              <xsl:element name="a">
                <xsl:attribute name="href">
                  <xsl:value-of select="DHEBoardURL/URL"/>
                </xsl:attribute>
                <xsl:value-of select="DHEBoardURL/URL"/>
              </xsl:element>
            </td>
          </tr>
        </xsl:for-each>
      </table>

      <br/><h2>Chassis Rear Slot Stuffing Table</h2>

      <table border="1" cellspacing="1" cellpadding="0">
        <tr bgcolor="#9acd32">
          <th>Slot Number</th>
          <th>Transition Board Type</th>
          <th>Identity Code</th>
          <th>Serial Number</th>
          <th>File Name</th>
        </tr>
        <xsl:for-each select="DHESlot">
          <xsl:variable name="Transition" select="DHETransitionURL/URL" />
          <tr>
            <td align="center"><xsl:value-of select="@position"/></td>
            <td align="left">
              <xsl:value-of select="document($Transition)/DHETransition/BoardName/NAME"/>
            </td>
            <td align="center">
              <xsl:value-of select="document($Transition)/DHETransition/BoardIdentity"/>
            </td>
            <td align="center">
              <xsl:value-of select="document($Transition)/DHETransition/BoardSerialNumber"/>
            </td>
            <td align="left">
              <xsl:element name="a">
                <xsl:attribute name="href">
                  <xsl:value-of select="DHETransitionURL/URL"/>
                </xsl:attribute>
                <xsl:value-of select="DHETransitionURL/URL"/>
              </xsl:element>
            </td>
          </tr>
        </xsl:for-each>
      </table>

      <br/><h2>Power Requirements</h2>

      <table border="1" cellspacing="1" cellpadding="0">
        <tr bgcolor="#9acd32">
          <th>Designation</th>
          <th>Voltage</th>
          <th>Usage</th>
          <th>Current Amps (Avg)</th>
          <th>Current Amps (Peak)</th>
        </tr>
        <tr>
          <td align="center">
            <xsl:text>+3.3VD</xsl:text>
          </td>
          <td align="center">
            <xsl:value-of select="document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='P3.3VD']/VOLTS" />
          </td>
          <td align="center">
            <xsl:value-of select="document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='P3.3VD']/VOLTS/@type" />
          </td>
          <td align="center">
            <xsl:value-of select="substring(sum(document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='P3.3VD']/AMPS[@context='average']/.),1,4)" />
          </td>
          <td align="center">
            <xsl:value-of select="substring(sum(document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='P3.3VD']/AMPS[@context='max']/.),1,4)" />
          </td>
        </tr>         

        <tr>
          <td align="center">
            <xsl:text>+5VD</xsl:text>
          </td>
          <td align="center">
            <xsl:value-of select="document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='P5VD']/VOLTS" />
          </td>
          <td align="center">
            <xsl:value-of select="document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='P5VD']/VOLTS/@type" />
          </td>
          <td align="center">
            <xsl:value-of select="substring(sum(document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='P5VD']/AMPS[@context='average']/.),1,4)" />
          </td>
          <td align="center">
            <xsl:value-of select="substring(sum(document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='P5VD']/AMPS[@context='max']/.),1,4)" />
          </td>
        </tr>         

        <tr>
          <td align="center">
            <xsl:text>+5VA</xsl:text>
          </td>
          <td align="center">
            <xsl:value-of select="document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='P5VA']/VOLTS" />
          </td>
          <td align="center">
            <xsl:value-of select="document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='P5VA']/VOLTS/@type" />
          </td>
          <td align="center">
            <xsl:value-of select="substring(sum(document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='P5VA']/AMPS[@context='average']/.),1,4)" />
          </td>
          <td align="center">
            <xsl:value-of select="substring(sum(document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='P5VA']/AMPS[@context='max']/.),1,4)" />
          </td>
        </tr>         

        <tr>
          <td align="center">
            <xsl:text>-5VA</xsl:text>
          </td>
          <td align="center">
            <xsl:value-of select="document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='N5VA']/VOLTS" />
          </td>
          <td align="center">
            <xsl:value-of select="document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='N5VA']/VOLTS/@type" />
          </td>
          <td align="center">
            <xsl:value-of select="substring(sum(document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='N5VA']/AMPS[@context='average']/.),1,4)" />
          </td>
          <td align="center">
            <xsl:value-of select="substring(sum(document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='N5VA']/AMPS[@context='max']/.),1,4)" />
          </td>
        </tr>         

        <tr>
          <td align="center">
            <xsl:text>+15VA</xsl:text>
          </td>
          <td align="center">
            <xsl:value-of select="document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='P15VA']/VOLTS" />
          </td>
          <td align="center">
            <xsl:value-of select="document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='P15VA']/VOLTS/@type" />
          </td>
          <td align="center">
            <xsl:value-of select="substring(sum(document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='P15VA']/AMPS[@context='average']/.),1,4)" />
          </td>
          <td align="center">
            <xsl:value-of select="substring(sum(document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='P15VA']/AMPS[@context='max']/.),1,4)" />
          </td>
        </tr>         

        <tr>
          <td align="center">
            <xsl:text>-15VA</xsl:text>
          </td>
          <td align="center">
            <xsl:value-of select="document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='N15VA']/VOLTS" />
          </td>
          <td align="center">
            <xsl:value-of select="document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='N15VA']/VOLTS/@type" />
          </td>
          <td align="center">
            <xsl:value-of select="substring(sum(document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='N15VA']/AMPS[@context='average']/.),1,4)" />
          </td>
          <td align="center">
            <xsl:value-of select="substring(sum(document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='N15VA']/AMPS[@context='max']/.),1,4)" />
          </td>
        </tr>         

        <tr>
          <td align="center">
            <xsl:text>+HV1</xsl:text>
          </td>
          <td align="center">
            <xsl:value-of select="document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='PHV1']/VOLTS" />
          </td>
          <td align="center">
            <xsl:value-of select="document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='PHV1']/VOLTS/@type" />
          </td>
          <td align="center">
            <xsl:value-of select="substring(sum(document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='PHV1']/AMPS[@context='average']/.),1,4)" />
          </td>
          <td align="center">
            <xsl:value-of select="substring(sum(document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='PHV1']/AMPS[@context='max']/.),1,4)" />
          </td>
        </tr>         

        <tr>
          <td align="center">
            <xsl:text>-HV1</xsl:text>
          </td>
          <td align="center">
            <xsl:value-of select="document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='NHV1']/VOLTS" />
          </td>
          <td align="center">
            <xsl:value-of select="document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='NHV1']/VOLTS/@type" />
          </td>
          <td align="center">
            <xsl:value-of select="substring(sum(document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='NHV1']/AMPS[@context='average']/.),1,4)" />
          </td>
          <td align="center">
            <xsl:value-of select="substring(sum(document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='NHV1']/AMPS[@context='max']/.),1,4)" />
          </td>
        </tr>         

        <tr>
          <td align="center">
            <xsl:text>+HV2</xsl:text>
          </td>
          <td align="center">
            <xsl:value-of select="document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='PHV2']/VOLTS" />
          </td>
          <td align="center">
            <xsl:value-of select="document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='PHV2']/VOLTS/@type" />
          </td>
          <td align="center">
            <xsl:value-of select="substring(sum(document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='PHV2']/AMPS[@context='average']/.),1,4)" />
          </td>
          <td align="center">
            <xsl:value-of select="substring(sum(document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='PHV2']/AMPS[@context='max']/.),1,4)" />
          </td>
        </tr>         

        <tr>
          <td align="center">
            <xsl:text>-HV2</xsl:text>
          </td>
          <td align="center">
            <xsl:value-of select="document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='NHV2']/VOLTS" />
          </td>
          <td align="center">
            <xsl:value-of select="document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='NHV2']/VOLTS/@type" />
          </td>
          <td align="center">
            <xsl:value-of select="substring(sum(document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='NHV2']/AMPS[@context='average']/.),1,4)" />
          </td>
          <td align="center">
            <xsl:value-of select="substring(sum(document(//DHESlot/DHEBoardURL/URL)/DHEBoard/PowerRequirements/POWER[@name='NHV2']/AMPS[@context='max']/.),1,4)" />
          </td>
        </tr>         
      </table>

  </body> 
  </html>
</xsl:template>


<xsl:template match="DHEBoard">
  <html>
  <head>
      <title>DHEBoard</title>
  </head>
  <body>
      <p/><h2><xsl:text>DHE Board Description Record</xsl:text></h2>
      <table cellspacing="0" cellpadding="3" border="0">
        <tr>
          <td valign="center">
            <font size="+1">
              <xsl:text>DHE Board Name</xsl:text>
            </font>
          </td>
          <td>
            <table cellspacing="0" cellpadding="3" border="1" width="100%">
              <tr>
                <td align="center" valign="center" bgcolor="#9acd32">
                  <font size="+2">
                    <xsl:value-of select="BoardName/NAME"/>
                  </font>
                </td>
              </tr>
            </table>
          </td>
        </tr>
        <tr>
          <td valign="bottom"><font size="+1"><xsl:text>Description</xsl:text></font></td>
          <td valign="baseline"><xsl:value-of select="Description"/></td>
        </tr>
        <tr>
          <td valign="bottom"><font size="+1"><xsl:text>Identity code</xsl:text></font></td>
          <td valign="baseline"><xsl:value-of select="BoardIdentity"/></td>
        </tr>
        <tr>
          <td valign="bottom"><font size="+1"><xsl:text>Serial Number</xsl:text></font></td>
          <td valign="baseline"><xsl:value-of select="BoardSerialNumber"/></td>
        </tr>
        <tr>
          <td valign="bottom"><font size="+1"><xsl:text>Firmware Version (Source)</xsl:text></font></td>
          <td valign="baseline"><xsl:value-of select="Firmware/VERSION"/>
            <xsl:text> (</xsl:text> 
              <xsl:element name="a">
                <xsl:attribute name="href">
                  <xsl:value-of select="Firmware/URL"/>
                </xsl:attribute>
                <xsl:value-of select="Firmware/URL"/>
                <xsl:text>)</xsl:text> 
              </xsl:element>
          </td>
        </tr>
        <tr>
          <td valign="bottom"><font size="+1"><xsl:text>Test Data Record</xsl:text></font></td>
          <td valign="baseline">
              <xsl:element name="a">
                <xsl:attribute name="href">
                  <xsl:value-of select="BoardTestRecordURL/URL"/>
                </xsl:attribute>
                <xsl:value-of select="BoardTestRecordURL/URL"/>
              </xsl:element>
          </td>
        </tr>
      </table>

      <xsl:apply-templates select = "Documentation" />

      <xsl:apply-templates select = "RevisionHistory" />


<!-- Function Parameter Table -->

      <br/><font size="+1">Board Function Table</font>
       <table border="1" cellspacing="1" cellpadding="0">
        <tr bgcolor="#9acd32">
          <th>Function Name</th>
          <th>Funct Type</th>
          <th>Elements</th>
          <th>Address</th>
          <th>Units</th>
          <th>Set Method</th>
          <th>Set Convert</th>
          <th>Set Conversion Coefficients</th>
          <th>Get Method</th>
          <th>Get Convert</th>
          <th>Get Conversion Coefficients</th>
          <th>Max Value</th>
          <th>Min Value</th>
        </tr>
        <xsl:for-each select="BoardFunction/FUNCTION">
          <tr>
            <td><xsl:value-of select="FN_NAME"/></td>
            <td><xsl:value-of select="@type"/></td>
            <td align="center"><xsl:value-of select="FN_ELEMENTS"/></td>
            <td><xsl:text>0x</xsl:text><xsl:value-of select="FN_ADDRESS"/></td>
            <td><xsl:value-of select="FN_METHODS/@units"/></td>
            <td><xsl:value-of select="FN_METHODS/SET_METHOD/METHOD/@method"/></td>
            <td><xsl:value-of select="FN_METHODS/SET_METHOD/METHOD/@convert"/></td>
            <td>
              <font size="-1">
              <table cellspacing="3" cellpadding="1" border="0">
              <xsl:for-each select="FN_METHODS/SET_METHOD/METHOD/COEFFICIENT">
                <tr>
                  <td><xsl:value-of select="./@context"/></td>
                  <td><xsl:value-of select="."/></td>
                </tr>
              </xsl:for-each>
              </table>
              </font>
            </td>
            <td><xsl:value-of select="FN_METHODS/GET_METHOD/METHOD/@method"/></td>
            <td><xsl:value-of select="FN_METHODS/GET_METHOD/METHOD/@convert"/></td>
            <td>
              <font size="-1">
              <table cellspacing="3" cellpadding="1" border="0">
              <xsl:for-each select="FN_METHODS/GET_METHOD/METHOD/COEFFICIENT">
                <tr>
                  <td><xsl:value-of select="./@context"/></td>
                  <td><xsl:value-of select="."/></td>
                </tr>
              </xsl:for-each>
              </table>
              </font>
            </td>
            <td><xsl:value-of select="FN_LIMITS/MAX"/></td>
            <td><xsl:value-of select="FN_LIMITS/MIN"/></td>
          </tr>
        </xsl:for-each>
      </table>

<!-- Function Help Table -->

      <br/><font size="+1">Function Signals and Help table</font>
      <table border="1">
        <tr bgcolor="#9acd32">
          <th>Function</th>
          <th>Attribute Suffix</th>
          <th>Signal Type</th>
          <th>Signal Connector</th>
          <th>Signal Pin</th>
          <th>Help Text</th>
        </tr>
        <xsl:for-each select="BoardFunction/FUNCTION">
          <tr>
            <td><xsl:value-of select="FN_NAME"/></td>
            <td><xsl:value-of select="FN_PREFIX"/></td>
            <td><xsl:value-of select="FN_SIGNALS/SIGNAL/@type"/></td>
            <td><xsl:value-of select="FN_SIGNALS/SIGNAL/SIG_DESIG/CONNECTOR"/></td>
            <td><xsl:value-of select="FN_SIGNALS/SIGNAL/SIG_DESIG/PIN"/></td>
            <td><xsl:value-of select="FN_HELP"/></td>
          </tr>
        </xsl:for-each>
      </table>

      <xsl:apply-templates select = "PowerRequirements" />

  </body>
  </html>
</xsl:template>


<xsl:template match="DHETransition">

  <html>
  <head>
      <title>DHE Transition Board</title>
  </head>
  <body>
      <p/>
      <center>
        <font size="+2">
          <xsl:text>DHE Transition Board Description Record</xsl:text>
        </font>
      </center>
      <table cellspacing="0" cellpadding="3" border="0">
        <tr>
          <td valign="center">
            <font size="+1">
              <xsl:text>Transition Board Name</xsl:text>
            </font>
          </td>
          <td>
            <table cellspacing="0" cellpadding="3" border="1" width="100%">
              <tr>
                <td align="center" valign="center" bgcolor="#9acd32">
                  <font size="+2">
                    <xsl:value-of select="BoardName/NAME"/>
  				  </font>
                </td>
              </tr>
            </table>
          </td>
        </tr>
        <tr>
          <td valign="bottom">
            <font size="+1">
              <xsl:text>Description</xsl:text>
            </font>
          </td>
          <td valign="baseline">
            <xsl:value-of select="Description"/>
          </td>
        </tr>
        <tr>
          <td valign="bottom">
            <font size="+1"><xsl:text>Identity code</xsl:text>
          </font></td>
          <td valign="baseline">
            <xsl:value-of select="BoardIdentity"/>
          </td>
        </tr>
        <tr>
          <td valign="bottom">
            <font size="+1">
              <xsl:text>Serial Number</xsl:text>
            </font>
          </td>
          <td valign="baseline">
            <xsl:value-of select="BoardSerialNumber"/>
          </td>
        </tr>
      </table>

      <xsl:apply-templates select = "Documentation" />

      <xsl:apply-templates select = "RevisionHistory" />

      <xsl:apply-templates select = "TransitionSignals" />

      <xsl:apply-templates select = "PowerRequirements" />

    </body>
  </html>
  
</xsl:template>


<xsl:template match="TransitionSignals">

      <p />
      <table border="1" cellspacing="0" cellpadding="1">
        <tr>
          <td align="center" bgcolor="#9acd32">
            <xsl:text>Transition Board Signals</xsl:text>
          </td>
          <td align="center" bgcolor="#9acd32">
            <xsl:text>Signal Paths (</xsl:text>
            <font color="0000FF"><xsl:text>Board Name - </xsl:text></font>
            <font color="000000"><xsl:text>Connector - </xsl:text></font>
            <font color="FF0000"><xsl:text>Signal Name - </xsl:text></font>
            <font color="308020"><xsl:text>(Signal Type) - </xsl:text></font>
            <font color="800080"><xsl:text>Function Name</xsl:text></font>
            <xsl:text>)</xsl:text>
            
          </td>
        </tr>
              <xsl:for-each select="SIGNAL">
                <tr>
                  <td align="left">
                    <font color="FF0000">
                      <xsl:value-of select="SIG_NAME"/>
                    </font>
                    <font color="308020">
                      <xsl:text> (</xsl:text>
                      <xsl:value-of select="@type"/>
                      <xsl:text>)</xsl:text>
                    </font>                    
                    <xsl:text> </xsl:text>
                    <xsl:value-of select="SIG_DESIG/CONNECTOR"/>
                    <xsl:text>:</xsl:text>
                    <xsl:value-of select="SIG_DESIG/PIN"/>
	              </td>	              
	              <td>
	                <xsl:for-each select="SIG_DESTINATION">
                      <xsl:if test="DEST_URL/URL">
                        <table cellspacing="0" cellpadding="2" border="0">
                          <tr>
                            <xsl:call-template name="SIGNAL">
                              <xsl:with-param name="url" select="DEST_URL/URL" />
                              <xsl:with-param name="con" select="SIGNAL/SIG_DESIG/CONNECTOR" />
                              <xsl:with-param name="pin" select="SIGNAL/SIG_DESIG/PIN" />
                              <xsl:with-param name="mode" select="../@type" />
                            </xsl:call-template>
                          </tr>
                        </table>
                      </xsl:if>
                    </xsl:for-each>
                  </td>
                </tr>
              </xsl:for-each>
      </table>
</xsl:template>


<xsl:template match="RevisionHistory">

<!-- Board History -->
      <br/>
      <font size="+1">
        <xsl:text>Revision History</xsl:text>
      </font>
      <table border="1" cellpadding="2" cellspacing="0">
        <tr bgcolor="#9acd32">
          <th>Date</th>
          <th>Author</th>
          <th>Revision</th>
        </tr>
        <xsl:for-each select="HISTORY">
          <tr>
            <td><xsl:value-of select="DATE"/></td>
            <td><xsl:value-of select="AUTHOR"/></td>
            <td><xsl:value-of select="REVISION"/></td>
          </tr>
        </xsl:for-each>
      </table>

</xsl:template>

<xsl:template match="Documentation">

<!-- Board Documentation -->
      <br/>
      <font size="+1">
        <xsl:text>Relevent Documentation</xsl:text>
      </font>
      <table border="1" cellpadding="2" cellspacing="0">
        <tr bgcolor="#9acd32">
          <th>Document</th>
          <th>Domain</th>
          <th>URL</th>
        </tr>
        <xsl:for-each select="DOCUMENT">
          <tr>
            <td><xsl:value-of select="TITLE"/></td>
            <td><xsl:value-of select="DOMAIN"/></td>

            <td>
              <xsl:element name="a">
                <xsl:attribute name="href">
                  <xsl:value-of select="URL"/>
                </xsl:attribute>
                <xsl:value-of select="URL" />
              </xsl:element>
            </td>
          </tr>
        </xsl:for-each>
      </table>

</xsl:template>


<xsl:template match="PowerRequirements">

<!-- Board Power requirements -->
      <br/><font size="+1">Power Requirements</font>
      <table border="1">
        <tr bgcolor="#9acd32">
          <th>Supply Voltage</th>
          <th>Supply Current</th>
        </tr>
        <xsl:for-each select="POWER">
          <tr>
            <td align="center"><xsl:value-of select="VOLTS/@type"/><xsl:text> </xsl:text><xsl:value-of select="VOLTS"/><xsl:text> </xsl:text><xsl:value-of select="VOLTS/@units"/></td>
            <td>            
              <table cellspacing="1" cellpadding="0" border="0">
                <xsl:for-each select="AMPS">
                <tr>
                  <td align="left"><xsl:value-of select="./@context"/></td>
                  <td align="right"><xsl:value-of select="."/><xsl:text> </xsl:text><xsl:value-of select="./@units"/></td>
                </tr>
              </xsl:for-each>
              </table>
            </td>
          </tr>
        </xsl:for-each>
      </table>

</xsl:template>


</xsl:stylesheet>