# CCD Board Testing Station Setup Mode File
# Version 1 - Peter Moore    - 22 AUG 2005 - Adapted from _ccdlabSTIS system    
##                           - 27 SEPT 2006 - Added fast bias control for local testing
#
# Attribute Name  = Value   #Comments
## Preamble - Kill the sequencer run flag if set
mcbseqEnable=0
#
## Bring the Boards online with the system clocks
mcbBkplnSlct=0   # for a 6 slot backplane
acqClkEnbl=1     # Enable acquistion board System clock
clkClkEnbl=1     # Enable clock on clock and bias board
#
## Reset the boards to condition them
resetCcd=1       # Reset the CCD acquisition board
resetClk=1       # and clock and bias board
#
## Disable the clock and bias outputs
clkClkPort=0     # Write zero to clock register to enable board
clkOutputEnblReg=0
#
## Setup some software defaults
arrayID=STIS_2Kx2K
arrayType=STIS
mosaicRows=1
mosaicCols=1
xPreScan=24     # 24 prescan in x 
xPostScan=64    # 64 postscan in x
yPostScan=88    # 88 post scan in y
numOutputs=4    # 4 output channels
outputCfg=0     # N.A. when numOutputs is 4 
pxlRows=2048
pxlCols=2048
xStart[0]=1
yStart[0]=1
finDataType=32   # DHS_UINT four bytes 32 bits
frmsPerRdOut=1   # number of readout for one simple exposure
captureMode=1    # capture mode 0=NORMAL, 1=SEP, 2=BLOCKREAD
expMode=0        # mode of the exposure
processMode=0    # Processing mode -- Switch off the telemetry collection
expVector=1      # 1 = Normal Clr,Int,Read readout, 4=Read only
asyncVector=0    # Currently not used.
rawPxlSize=4     # number of Bytes in a raw pixel value
finPxlSize=4     # number of Bytes in a finished pixel value
avNameSIze=32    # Max character length of attribute name
avValueSize=32   # Max character length of attribute value
avCommentSize=64 # Max character length of attribute comment
#
## Fast Bias Setup
FBias0Dac[]=0
FBias1Dac[]=0
FBias2Dac[]=0
FBias3Dac[]=0
FBias4Dac[]=0
FBias5Dac[]=0
FBias6Dac[]=0
FBias7Dac[]=0
FBias0Dac[0]=-7.5 # Setup fast bias channel 0 as a shutter clock
FBias0Dac[1]=7.5
FBias0123Trig=0   # Set the fast bias dacs up
FBias4567Trig=0
#
## Clocks voltages setup
S1aLowDac=-5.0
S1aHiDac=5.0
S1bLowDac=-5.0
S1bHiDac=5.0
S1cLowDac=-5.0
S1cHiDac=5.0
S1dLowDac=-5.0
S1dHiDac=5.0
S2aLowDac=-5.0
S2aHiDac=5.0
S2bLowDac=-5.0
S2bHiDac=5.0
S2cLowDac=-5.0
S2cHiDac=5.0
S2dLowDac=-5.0
S2dHiDac=5.0
S3aLowDac=-5.0
S3aHiDac=5.0
S3bLowDac=-5.0
S3bHiDac=5.0
S3cLowDac=-5.0
S3cHiDac=5.0
S3dLowDac=-5.0
S3dHiDac=5.0
SWaLowDac=-5.0
SWaHiDac=5.0
SWbLowDac=-5.0
SWbHiDac=5.0
SWcLowDac=-5.0
SWcHiDac=5.0
SWdLowDac=-5.0
SWdHiDac=5.0
TGabLowDac=-8.5
TGabHiDac=2.12
TGcdLowDac=-8.5
TGcdHiDac=2.12
P1abLowDac=-8.5
P1abHiDac=2.12
P1cdLowDac=-8.5
P1cdHiDac=2.12
P2abLowDac=-8.5
P2abHiDac=2.12
P2cdLowDac=-8.5
P2cdHiDac=2.12
P3abLowDac=-6.0
P3abHiDac=6.0
P3cdLowDac=-6.0
P3cdHiDac=6.0
RGaLowDac=0.0
RGaHiDac=10.0
RGbLowDac=0.0
RGbHiDac=10.0
RGcLowDac=0.0
RGcHiDac=10.0
RGdLowDac=0.0
RGdHiDac=10.0
#
## CCD board Telemetry mode setup
CCD_HVBIASTELMODE[]=12      # Internal Clock Mode, +/-10V full scale.
#
## Bias voltages setup
CCD_HVBIASES[]=685      # Set all +HV biases to nominal 5v 
CCD_HVBIASES[16]=3410   # Set all -HV biases to nominal -5v 
CCD_HVBIASES[17]=3410       
CCD_HVBIASES[18]=3410       
CCD_HVBIASES[19]=3410       
CCD_HVBIASES[20]=3410       
CCD_HVBIASES[21]=3410       
CCD_HVBIASES[22]=3410       
CCD_HVBIASES[23]=3410       

## Bias voltages setup for STIS
DD_ADac=25.50
DD_BDac=25.50
DD_CDac=25.50
DD_DDac=25.50
OD_ADac=14.00
OD_BDac=14.00
OD_CDac=14.00
OD_DDac=14.00
LG_ADac=4.8    # Modified to use clock and bias board rail
# LG_BDac=-1.00
# LG_CDac=-1.00
# LG_DDac=-1.00
#
## Exposure Attribute setup
filename=FRED    # Default file name prefix
imageFile=FRED   # To satisfy bug in generic library (?)
intTime=0        # Default to 0 seconds
#
## Sequencer attributes
rows=1112  # 1024 image rows + 88 post per output
cols=1112  # 1024 image cols + 24 pre + 64 post per output
rowBin=1
colBin=1
rowSkip=0
colSkip=0
rstTime=10
dwellTime=10
holdTime=5
#
mpuSeqClkDiv=0
contRun=0
#
## Offset voltages setup
CCD_VOFFSETS[]=1024    # Set all ADC offsets safe
CCD_VOFFSETS[1]=890    # except channel 1 which has a different topology
#
## Video channels setup (High Gain)
CCD_ADCCFG[]=4
#
## Initialize some of the ports
CdsReg=0x136      # Kill all CDS activity
DopReg=0          # Write zeros to DOP port
#
## Acquisition Board setup ##
Redirect[0]=1
Redirect[1]=3     # check out odd channels at the present time
Redirect[2]=5
Redirect[3]=7
Redirect[4]=0
Redirect[5]=0
Redirect[6]=0
Redirect[7]=0
Redirect[8]=0
Redirect[9]=0
Redirect[10]=0
Redirect[11]=0
Redirect[12]=0
Redirect[13]=0
Redirect[14]=0
XfrCount=4     # four pixels to xfer for each CTC
DataWidth=1    # Select 16 bit data mode Bits 16:1
AdcMode=0      # Slow mode (i.e data xfer after conversion)
PipePriority=0 # Only one acquisition board so highest priority
PipeEnbl=1     # Enable pipeline data writes
#
## Setup the voltages and enable to array
CdsEnbl=1           # Enable the CDS function
HVBiasEnbl=1
CpldLedEnable=1     # Switch off the CPLD LEDs
clkBiasEnbl0=1   # for LG bias supplies
clkClockEnbl=1      # enable the clock signals
clkFBiasEnbl=1      # enable fast biases
#
## Diagnostics ...
mcbMpuSeqBusReq=1   # Led on mcb for sequencer bus req
ccdBrdSel=0         # Ditto for CCD board
ccdCdsLoad=1        # light the sky when cds load strobe present
labSystem=1         # Kill long star date file names
## CB Board auxiliary functions
clkP2MuxSlct=17   # Look at TG 
clkP1MuxSlct=0    # Look at S1a
clkD5LedCntrl=1   # Switch off the lights ...

# mcbseqEnable= 1   # start sequencer
